'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_ARRAY_H__
'#define __G_ARRAY_H__

#IF NOT %DEF(%GARRAY_INC)
    %GARRAY_INC = 1

#INCLUDE ONCE "gtypes.inc"

'G_BEGIN_DECLS

'typedef struct _GArray      GArray;
'typedef struct _GByteArray   GByteArray;
'typedef struct _GPtrArray   GPtrArray;

'struct _GArray
'{
'  gchar *data;
'  guint len;
'};

TYPE GArray
   data AS ASCIIZ PTR
   len  AS DWORD
END TYPE

'struct _GByteArray
'{
'  guint8 *data;
'  guint     len;
'};

TYPE GByteArray
   data AS BYTE PTR
   len  AS DWORD
END TYPE

'struct _GPtrArray
'{
'  gpointer *pdata;
'  guint       len;
'};

TYPE GPtrArray
   pdata AS DWORD PTR
   len   AS DWORD
END TYPE

'/* Resizable arrays. remove fills any cleared spot and shortens the
' * array, while preserving the order. remove_fast will distort the
' * order by moving the last element to the position of the removed.
' */

' ========================================================================================
'#define g_array_append_val(a,v)     g_array_append_vals (a, &(v), 1)
' ========================================================================================
MACRO g_array_append_val(a,v) = g_array_append_vals (a, v, 1)

' ========================================================================================
'#define g_array_prepend_val(a,v)  g_array_prepend_vals (a, &(v), 1)
' ========================================================================================
MACRO g_array_prepend_val(a,v) = g_array_prepend_vals (a, v, 1)

' ========================================================================================
'#define g_array_insert_val(a,i,v) g_array_insert_vals (a, i, &(v), 1)
' ========================================================================================
MACRO g_array_insert_val(a,i,v) = g_array_insert_vals (a, i, v, 1)

' ========================================================================================
'#define g_array_index(a,t,i)      (((t*) (void *) (a)->data) [(i)])
' ========================================================================================

' ========================================================================================
'GArray* g_array_new               (gboolean            zero_terminated,
'                                   gboolean            clear_,
'                                   guint               element_size);
' ========================================================================================
DECLARE FUNCTION g_array_new CDECL LIB $GLIB_DLLNAME ALIAS "g_array_new" ( _
   BYVAL LONG _                             ' gboolean            zero_terminated
 , BYVAL LONG _                             ' gboolean            clear_
 , BYVAL DWORD _                            ' guint               element_size
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_sized_new         (gboolean          zero_terminated,
'                                   gboolean          clear_,
'                                   guint             element_size,
'                                   guint             reserved_size);
' ========================================================================================
DECLARE FUNCTION g_array_sized_new CDECL LIB $GLIB_DLLNAME ALIAS "g_array_sized_new" ( _
   BYVAL LONG _                             ' gboolean            zero_terminated
 , BYVAL LONG _                             ' gboolean            clear_
 , BYVAL DWORD _                            ' guint               element_size
 , BYVAL DWORD _                            ' guint               reserved_size
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'gchar*  g_array_free              (GArray           *array,
'                                   gboolean          free_segment);
' ========================================================================================
DECLARE FUNCTION g_array_free CDECL LIB $GLIB_DLLNAME ALIAS "g_array_free" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL LONG _                             ' gboolean          free_segment
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'GArray* g_array_append_vals       (GArray           *array,
'                                   gconstpointer     data,
'                                   guint             len);
' ========================================================================================
DECLARE FUNCTION g_array_append_vals CDECL LIB $GLIB_DLLNAME ALIAS "g_array_append_vals" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' gconstpointer     data
 , BYVAL DWORD _                            ' guint             len
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_prepend_vals      (GArray           *array,
'                                   gconstpointer     data,
'                                   guint             len);
' ========================================================================================
DECLARE FUNCTION g_array_prepend_vals CDECL LIB $GLIB_DLLNAME ALIAS "g_array_prepend_vals" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' gconstpointer     data
 , BYVAL DWORD _                            ' guint             len
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_insert_vals       (GArray           *array,
'                                   guint             index_,
'                                   gconstpointer     data,
'                                   guint             len);
' ========================================================================================
DECLARE FUNCTION g_array_insert_vals CDECL LIB $GLIB_DLLNAME ALIAS "g_array_insert_vals" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' guint             index_
 , BYVAL DWORD _                            ' gconstpointer     data
 , BYVAL DWORD _                            ' guint             len
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_set_size          (GArray           *array,
'                                   guint             length);
' ========================================================================================
DECLARE FUNCTION g_array_set_size CDECL LIB $GLIB_DLLNAME ALIAS "g_array_set_size" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' guint             length
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_remove_index      (GArray           *array,
'                                   guint             index_);
' ========================================================================================
DECLARE FUNCTION g_array_remove_index CDECL LIB $GLIB_DLLNAME ALIAS "g_array_remove_index" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_remove_index_fast (GArray           *array,
'                                   guint             index_);
' ========================================================================================
DECLARE FUNCTION g_array_remove_index_fast CDECL LIB $GLIB_DLLNAME ALIAS "g_array_remove_index_fast" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'GArray* g_array_remove_range      (GArray           *array,
'                                   guint             index_,
'                                   guint             length);
' ========================================================================================
DECLARE FUNCTION g_array_remove_range CDECL LIB $GLIB_DLLNAME ALIAS "g_array_remove_range" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' guint             index_
 , BYVAL DWORD _                            ' guint             length
 ) AS DWORD                                 ' GArray*

' ========================================================================================
'void    g_array_sort              (GArray           *array,
'                                   GCompareFunc      compare_func);
' ========================================================================================
DECLARE SUB g_array_sort CDECL LIB $GLIB_DLLNAME ALIAS "g_array_sort" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 )                                          ' void

' ========================================================================================
'void    g_array_sort_with_data    (GArray           *array,
'                                   GCompareDataFunc  compare_func,
'                                   gpointer          user_data);
' ========================================================================================
DECLARE SUB g_array_sort_with_data CDECL LIB $GLIB_DLLNAME ALIAS "g_array_sort_with_data" ( _
   BYVAL GArray PTR _                       ' GArray           *array
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

'/* Resizable pointer array.  This interface is much less complicated
' * than the above.  Add appends a pointer.  Remove fills any cleared
' * spot and shortens the array. remove_fast will again distort order.
' */

' ========================================================================================
'#define    g_ptr_array_index(array,index_) ((array)->pdata)[index_]
' ========================================================================================
MACRO g_ptr_array_index(array_,index_) = @array_.@pdata[index_]

' ========================================================================================
'GPtrArray* g_ptr_array_new                (void);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_new CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_new" ( _
 ) AS DWORD                                 ' GPtrArray*

' ========================================================================================
'GPtrArray* g_ptr_array_sized_new          (guint             reserved_size);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_sized_new CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_sized_new" ( _
   BYVAL DWORD _                            ' guint             reserved_size
 ) AS DWORD                                 ' GPtrArray*

' ========================================================================================
'gpointer*  g_ptr_array_free               (GPtrArray        *array,
'                                           gboolean          free_seg);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_free CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_free" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL LONG _                             ' gboolean          free_seg
 ) AS DWORD                                 ' gpointer*

' ========================================================================================
'void       g_ptr_array_set_size           (GPtrArray        *array,
'                                           gint              length);
' ========================================================================================
DECLARE SUB g_ptr_array_set_size CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_set_size" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL LONG _                             ' gint              length
 )                                          ' void

' ========================================================================================
'gpointer   g_ptr_array_remove_index       (GPtrArray        *array,
'                                           guint             index_);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_remove_index CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_remove_index" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'gpointer   g_ptr_array_remove_index_fast  (GPtrArray        *array,
'                                           guint             index_);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_remove_index_fast CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_remove_index_fast" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'gboolean   g_ptr_array_remove             (GPtrArray        *array,
'                                           gpointer          data);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_remove CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_remove" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' gpointer          data
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean   g_ptr_array_remove_fast        (GPtrArray        *array,
'                                           gpointer          data);
' ========================================================================================
DECLARE FUNCTION g_ptr_array_remove_fast CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_remove_fast" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' gpointer          data
 ) AS LONG                                  ' gboolean

' ========================================================================================
'void       g_ptr_array_remove_range       (GPtrArray        *array,
'                                           guint             index_,
'                                           guint             length);
' ========================================================================================
DECLARE SUB g_ptr_array_remove_range CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_remove_range" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' guint             index_
 , BYVAL DWORD _                            ' guint             length
 )                                          ' void

' ========================================================================================
'void       g_ptr_array_add                (GPtrArray        *array,
'                                           gpointer          data);
' ========================================================================================
DECLARE SUB g_ptr_array_add CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_add" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' gpointer          data
 )                                          ' void

' ========================================================================================
'void       g_ptr_array_sort               (GPtrArray        *array,
'                                           GCompareFunc      compare_func);
' ========================================================================================
DECLARE SUB g_ptr_array_sort CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_sort" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 )                                          ' void

' ========================================================================================
'void       g_ptr_array_sort_with_data     (GPtrArray        *array,
'                                           GCompareDataFunc  compare_func,
'                                           gpointer          user_data);
' ========================================================================================
DECLARE SUB g_ptr_array_sort_with_data CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_sort_with_data" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' GCompareDataFunc  compare_func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

' ========================================================================================
'void       g_ptr_array_foreach            (GPtrArray        *array,
'                                           GFunc             func,
'                                           gpointer          user_data);
' ========================================================================================
DECLARE SUB g_ptr_array_foreach CDECL LIB $GLIB_DLLNAME ALIAS "g_ptr_array_foreach" ( _
   BYVAL GPtrArray PTR _                    ' GPtrArray        *array
 , BYVAL DWORD _                            ' GFunc             func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

'/* Byte arrays, an array of guint8.  Implemented as a GArray,
' * but type-safe.
' */

' ========================================================================================
'GByteArray* g_byte_array_new               (void);
' ========================================================================================
DECLARE FUNCTION g_byte_array_new CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_new" ( _
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_sized_new         (guint             reserved_size);
' ========================================================================================
DECLARE FUNCTION g_byte_array_sized_new CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_sized_new" ( _
   BYVAL DWORD _                            ' guint             reserved_size
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'guint8*     g_byte_array_free              (GByteArray       *array,
'                                            gboolean          free_segment);
' ========================================================================================
DECLARE FUNCTION g_byte_array_free CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_free" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL LONG _                             ' gboolean          free_segment
 ) AS DWORD                                 ' guint8*

' ========================================================================================
'GByteArray* g_byte_array_append            (GByteArray       *array,
'                                            const guint8     *data,
'                                            guint             len);
' ========================================================================================
DECLARE FUNCTION g_byte_array_append CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_append" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYREF ANY _                              ' const guint8     *data
 , BYVAL DWORD _                            ' guint             len
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_prepend           (GByteArray       *array,
'                                            const guint8     *data,
'                                            guint             len);
' ========================================================================================
DECLARE FUNCTION g_byte_array_prepend CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_prepend" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYREF ANY _                              ' const guint8     *data
 , BYVAL DWORD _                            ' guint             len
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_set_size          (GByteArray       *array,
'                                            guint             length);
' ========================================================================================
DECLARE FUNCTION g_byte_array_set_size CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_set_size" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' guint             length
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_remove_index      (GByteArray       *array,
'                                            guint             index_);
' ========================================================================================
DECLARE FUNCTION g_byte_array_remove_index CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_remove_index" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_remove_index_fast (GByteArray       *array,
'                                            guint             index_);
' ========================================================================================
DECLARE FUNCTION g_byte_array_remove_index_fast CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_remove_index_fast" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' guint             index_
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'GByteArray* g_byte_array_remove_range      (GByteArray       *array,
'                                            guint             index_,
'                                            guint             length);
' ========================================================================================
DECLARE FUNCTION g_byte_array_remove_range CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_remove_range" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' guint             index_
 , BYVAL DWORD _                            ' guint             length
 ) AS DWORD                                 ' GByteArray*

' ========================================================================================
'void        g_byte_array_sort              (GByteArray       *array,
'                                            GCompareFunc      compare_func);
' ========================================================================================
DECLARE SUB g_byte_array_sort CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_sort" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 )                                          ' void

' ========================================================================================
'void        g_byte_array_sort_with_data    (GByteArray       *array,
'                                            GCompareDataFunc  compare_func,
'                                            gpointer          user_data);
' ========================================================================================
DECLARE SUB g_byte_array_sort_with_data CDECL LIB $GLIB_DLLNAME ALIAS "g_byte_array_sort_with_data" ( _
   BYVAL GByteArray PTR _                   ' GByteArray       *array
 , BYVAL DWORD _                            ' GCompareDataFunc  compare_func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

'G_END_DECLS

'#endif /* __G_ARRAY_H__ */
#ENDIF   ' /* __GARRAY_INC__ */
