'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_ASYNCQUEUE_H__
'#define __G_ASYNCQUEUE_H__

#IF NOT %DEF(%GASYNCQUEUE_INC)
    %GASYNCQUEUE_INC = 1

'#include <glib/gthread.h>

'G_BEGIN_DECLS

'typedef struct _GAsyncQueue GAsyncQueue;

'/* Asyncronous Queues, can be used to communicate between threads */

'/* Get a new GAsyncQueue with the ref_count 1 */
' ========================================================================================
'GAsyncQueue*  g_async_queue_new                 (void);
' ========================================================================================
DECLARE FUNCTION g_async_queue_new CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_new" ( _
 ) AS DWORD                                 ' GAsyncQueue*

' ========================================================================================
'GAsyncQueue*  g_async_queue_new_full            (GDestroyNotify item_free_func);
' ========================================================================================
DECLARE FUNCTION g_async_queue_new_full CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_new_full" ( _
   BYVAL DWORD _                            ' GDestroyNotify item_free_func
 ) AS DWORD                                 ' GAsyncQueue*

'/* Lock and unlock a GAsyncQueue. All functions lock the queue for
' * themselves, but in certain cirumstances you want to hold the lock longer,
' * thus you lock the queue, call the *_unlocked functions and unlock it again.
' */
' ========================================================================================
'void         g_async_queue_lock                 (GAsyncQueue      *queue);
' ========================================================================================
DECLARE SUB g_async_queue_lock CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_lock" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 )                                          ' void

' ========================================================================================
'void         g_async_queue_unlock               (GAsyncQueue      *queue);
' ========================================================================================
DECLARE SUB g_async_queue_unlock CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_unlock" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 )                                          ' void

'/* Ref and unref the GAsyncQueue. */
' ========================================================================================
'GAsyncQueue* g_async_queue_ref                  (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_ref CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_ref" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS DWORD                                 ' GAsyncQueue*

' ========================================================================================
'void         g_async_queue_unref                (GAsyncQueue      *queue);
' ========================================================================================
DECLARE SUB g_async_queue_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_unref" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 )                                          ' void

'#ifndef G_DISABLE_DEPRECATED
'/* You don't have to hold the lock for calling *_ref and *_unref anymore. */
'void         g_async_queue_ref_unlocked         (GAsyncQueue      *queue);
'void         g_async_queue_unref_and_unlock     (GAsyncQueue      *queue);
'#endif /* !G_DISABLE_DEPRECATED */

'/* Push data into the async queue. Must not be NULL. */
' ========================================================================================
'void         g_async_queue_push                 (GAsyncQueue      *queue,
'                                                 gpointer          data);
' ========================================================================================
DECLARE SUB g_async_queue_push CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_push" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' gpointer          data
 )                                          ' void

' ========================================================================================
'void         g_async_queue_push_unlocked        (GAsyncQueue      *queue,
'                                                 gpointer          data);
' ========================================================================================
DECLARE SUB g_async_queue_push_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_push_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' gpointer          data
 )                                          ' void

' ========================================================================================
'void         g_async_queue_push_sorted          (GAsyncQueue      *queue,
'                                                 gpointer          data,
'                                                 GCompareDataFunc  func,
'                                                 gpointer          user_data);
' ========================================================================================
DECLARE SUB g_async_queue_push_sorted CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_push_sorted" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' gpointer          data
 , BYVAL DWORD _                            ' GCompareDataFunc  func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

' ========================================================================================
'void         g_async_queue_push_sorted_unlocked (GAsyncQueue      *queue,
'                                                 gpointer          data,
'                                                 GCompareDataFunc  func,
'                                                 gpointer          user_data);
' ========================================================================================
DECLARE SUB g_async_queue_push_sorted_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_push_sorted_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' gpointer          data
 , BYVAL DWORD _                            ' GCompareDataFunc  func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

'/* Pop data from the async queue. When no data is there, the thread is blocked
' * until data arrives.
' */
' ========================================================================================
'gpointer     g_async_queue_pop                  (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_pop CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_pop" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'gpointer     g_async_queue_pop_unlocked         (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_pop_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_pop_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS DWORD                                 ' gpointer

'/* Try to pop data. NULL is returned in case of empty queue. */
' ========================================================================================
'gpointer     g_async_queue_try_pop              (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_try_pop CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_try_pop" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'gpointer     g_async_queue_try_pop_unlocked     (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_try_pop_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_try_pop_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS DWORD                                 ' gpointer


'/* Wait for data until at maximum until end_time is reached. NULL is returned
' * in case of empty queue.
' */
' ========================================================================================
'gpointer     g_async_queue_timed_pop            (GAsyncQueue      *queue,
'                                                 GTimeVal         *end_time);
' ========================================================================================
DECLARE FUNCTION g_async_queue_timed_pop CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_timed_pop" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYREF GTimeVal _                         ' GTimeVal         *end_time
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'gpointer     g_async_queue_timed_pop_unlocked   (GAsyncQueue      *queue,
'                                                 GTimeVal         *end_time);
' ========================================================================================
DECLARE FUNCTION g_async_queue_timed_pop_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_timed_pop_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYREF GTimeVal _                         ' GTimeVal         *end_time
 ) AS DWORD                                 ' gpointer

'/* Return the length of the queue. Negative values mean that threads
' * are waiting, positve values mean that there are entries in the
' * queue. Actually this function returns the length of the queue minus
' * the number of waiting threads, g_async_queue_length == 0 could also
' * mean 'n' entries in the queue and 'n' thread waiting. Such can
' * happen due to locking of the queue or due to scheduling.
' */
' ========================================================================================
'gint         g_async_queue_length               (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_length CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_length" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS LONG                                  ' gint

' ========================================================================================
'gint         g_async_queue_length_unlocked      (GAsyncQueue      *queue);
' ========================================================================================
DECLARE FUNCTION g_async_queue_length_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_length_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 ) AS LONG                                  ' gint

' ========================================================================================
'void         g_async_queue_sort                 (GAsyncQueue      *queue,
'                                                 GCompareDataFunc  func,
'                                                 gpointer          user_data);
' ========================================================================================
DECLARE SUB g_async_queue_sort CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_sort" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' GCompareDataFunc  func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

' ========================================================================================
'void         g_async_queue_sort_unlocked        (GAsyncQueue      *queue,
'                                                 GCompareDataFunc  func,
'                                                 gpointer          user_data);
' ========================================================================================
DECLARE SUB g_async_queue_sort_unlocked CDECL LIB $GLIB_DLLNAME ALIAS "g_async_queue_sort_unlocked" ( _
   BYVAL DWORD _                            ' GAsyncQueue      *queue
 , BYVAL DWORD _                            ' GCompareDataFunc  func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

'/* Private API */
'GMutex*      _g_async_queue_get_mutex           (GAsyncQueue      *queue);

'G_END_DECLS

'#endif /* __G_ASYNCQUEUE_H__ */
#ENDIF   ' /* __GASYNCQUEUE_INC__ */
