'/* gchecksum.h - data hashing functions
' *
' * Copyright (C) 2007  Emmanuele Bassi  <ebassi@gnome.org>
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Library General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' * Library General Public License for more details.
' *
' * You should have received a copy of the GNU Library General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_CHECKSUM_H__
'#define __G_CHECKSUM_H__

#IF NOT %DEF(%GCHECKSUM_INC)
    %GCHECKSUM_INC = 1

#INCLUDE ONCE "gtypes.inc"

'G_BEGIN_DECLS

'/**
' * GChecksumType:
' * @G_CHECKSUM_MD5: Use the MD5 hashing algorithm
' * @G_CHECKSUM_SHA1: Use the SHA-1 hashing algorithm
' * @G_CHECKSUM_SHA256: Use the SHA-256 hashing algorithm
' *
' * The hashing algorithm to be used by #GChecksum when performing the
' * digest of some data.
' *
' * Note that the #GChecksumType enumeration may be extended at a later
' * date to include new hashing algorithm types.
' *
' * Since: 2.16
' */
'typedef enum {
'  G_CHECKSUM_MD5,
'  G_CHECKSUM_SHA1,
'  G_CHECKSUM_SHA256
'} GChecksumType;

%G_CHECKSUM_MD5    = 0
%G_CHECKSUM_SHA1   = 1
%G_CHECKSUM_SHA256 = 2

'/**
' * GChecksum:
' *
' * An opaque structure representing a checksumming operation.
' * To create a new GChecksum, use g_checksum_new(). To free
' * a GChecksum, use g_checksum_free().
' *
' * Since: 2.16
' */
'typedef struct _GChecksum       GChecksum;

' ========================================================================================
'gssize                g_checksum_type_get_length (GChecksumType checksum_type);
' ========================================================================================
DECLARE FUNCTION g_checksum_type_get_length CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_type_get_length" ( _
   BYVAL LONG _                             ' GChecksumType checksum_type
 ) AS LONG                                  ' gssize

' ========================================================================================
'GChecksum *           g_checksum_new        (GChecksumType     checksum_type);
' ========================================================================================
DECLARE FUNCTION g_checksum_new CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_new" ( _
   BYVAL LONG _                             ' GChecksumType checksum_type
 ) AS DWORD                                 ' GChecksum*

' ========================================================================================
'void                  g_checksum_reset      (GChecksum        *checksum);
' ========================================================================================
DECLARE SUB g_checksum_reset CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_reset" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 )                                          ' void

' ========================================================================================
'GChecksum *           g_checksum_copy       (const GChecksum  *checksum);
' ========================================================================================
DECLARE FUNCTION g_checksum_copy CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_copy" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 ) AS DWORD                                 ' GChecksum*

' ========================================================================================
'void                  g_checksum_free       (GChecksum        *checksum);
' ========================================================================================
DECLARE SUB g_checksum_free CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_free" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 )                                          ' void

' ========================================================================================
'void                  g_checksum_update     (GChecksum        *checksum,
'                                             const guchar     *data,
'                                             gssize            length);
' ========================================================================================
DECLARE SUB g_checksum_update CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_update" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 , BYREF ANY _                              ' const guchar     *data
 , BYVAL LONG _                             ' gssize            length
 )                                          ' void

' ========================================================================================
'G_CONST_RETURN gchar *g_checksum_get_string (GChecksum        *checksum);
' ========================================================================================
DECLARE FUNCTION g_checksum_get_string CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_get_string" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'void                  g_checksum_get_digest (GChecksum        *checksum,
'                                             guint8           *buffer,
'                                             gsize            *digest_len);
' ========================================================================================
DECLARE SUB g_checksum_get_digest CDECL LIB $GLIB_DLLNAME ALIAS "g_checksum_get_digest" ( _
   BYVAL DWORD _                            ' GChecksum        *checksum
 , BYREF ANY _                              ' guint8           *buffer
 , BYREF DWORD _                            ' gsize           *digest_len
 )                                          ' void

' ========================================================================================
'gchar *g_compute_checksum_for_data   (GChecksumType  checksum_type,
'                                      const guchar  *data,
'                                      gsize          length);
' ========================================================================================
DECLARE FUNCTION g_compute_checksum_for_data CDECL LIB $GLIB_DLLNAME ALIAS "g_compute_checksum_for_data" ( _
   BYVAL LONG _                             ' GChecksumType  checksum_type
 , BYREF ANY _                              ' const guchar  *data
 , BYVAL DWORD _                            ' gsize          length
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_compute_checksum_for_string (GChecksumType  checksum_type,
'                                      const gchar   *str,
'                                      gssize         length);
' ========================================================================================
DECLARE FUNCTION g_compute_checksum_for_string CDECL LIB $GLIB_DLLNAME ALIAS "g_compute_checksum_for_string" ( _
   BYVAL LONG _                             ' GChecksumType  checksum_type
 , BYREF ASCIIZ _                           ' const gchar   *str
 , BYVAL LONG _                             ' gssize         length
 ) AS DWORD                                 ' gchar*

'G_END_DECLS

'#endif /* __G_CHECKSUM_H__ */
#ENDIF   ' /* __GCHECKSUM_INC__ */
