'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_DATE_H__
'#define __G_DATE_H__

#IF NOT %DEF(%GDATE_INC)
   %GDATE_INC = 1

#INCLUDE ONCE "time.inc"

#INCLUDE ONCE "gtypes.inc"
#INCLUDE ONCE "gquark.inc"

'G_BEGIN_DECLS

'/* GDate
' *
' * Date calculations (not time for now, to be resolved). These are a
' * mutant combination of Steffen Beyer's DateCalc routines
' * (http://www.perl.com/CPAN/authors/id/STBEY/) and Jon Trowbridge's
' * date routines (written for in-house software).  Written by Havoc
' * Pennington <hp@pobox.com>
' */

'typedef gint32  GTime;
'typedef guint16 GDateYear;
'typedef guint8  GDateDay;   /* day of the month */
'typedef struct _GDate GDate;

'/* enum used to specify order of appearance in parsed date strings */
'typedef enum
'{
'  G_DATE_DAY   = 0,
'  G_DATE_MONTH = 1,
'  G_DATE_YEAR  = 2
'} GDateDMY;

%G_DATE_DAY   = 0?
%G_DATE_MONTH = 1?
%G_DATE_YEAR  = 2?

'/* actual week and month values */
'typedef enum
'{
'  G_DATE_BAD_WEEKDAY  = 0,
'  G_DATE_MONDAY       = 1,
'  G_DATE_TUESDAY      = 2,
'  G_DATE_WEDNESDAY    = 3,
'  G_DATE_THURSDAY     = 4,
'  G_DATE_FRIDAY       = 5,
'  G_DATE_SATURDAY     = 6,
'  G_DATE_SUNDAY       = 7
'} GDateWeekday;

%G_DATE_BAD_WEEKDAY  = 0?
%G_DATE_MONDAY       = 1?
%G_DATE_TUESDAY      = 2?
%G_DATE_WEDNESDAY    = 3?
%G_DATE_THURSDAY     = 4?
%G_DATE_FRIDAY       = 5?
%G_DATE_SATURDAY     = 6?
%G_DATE_SUNDAY       = 7?

'typedef enum
'{
'  G_DATE_BAD_MONTH = 0,
'  G_DATE_JANUARY   = 1,
'  G_DATE_FEBRUARY  = 2,
'  G_DATE_MARCH     = 3,
'  G_DATE_APRIL     = 4,
'  G_DATE_MAY       = 5,
'  G_DATE_JUNE      = 6,
'  G_DATE_JULY      = 7,
'  G_DATE_AUGUST    = 8,
'  G_DATE_SEPTEMBER = 9,
'  G_DATE_OCTOBER   = 10,
'  G_DATE_NOVEMBER  = 11,
'  G_DATE_DECEMBER  = 12
'} GDateMonth;

%G_DATE_BAD_MONTH = 0?
%G_DATE_JANUARY   = 1?
%G_DATE_FEBRUARY  = 2?
%G_DATE_MARCH     = 3?
%G_DATE_APRIL     = 4?
%G_DATE_MAY       = 5?
%G_DATE_JUNE      = 6?
%G_DATE_JULY      = 7?
%G_DATE_AUGUST    = 8?
%G_DATE_SEPTEMBER = 9?
%G_DATE_OCTOBER   = 10?
%G_DATE_NOVEMBER  = 11?
%G_DATE_DECEMBER  = 12?

'#define G_DATE_BAD_JULIAN 0U
'#define G_DATE_BAD_DAY    0U
'#define G_DATE_BAD_YEAR   0U

%G_DATE_BAD_JULIAN = 0?
%G_DATE_BAD_DAY    = 0?
%G_DATE_BAD_YEAR   = 0?

'/* Note: directly manipulating structs is generally a bad idea, but
' * in this case it's an *incredibly* bad idea, because all or part
' * of this struct can be invalid at any given time. Use the functions,
' * or you will get hosed, I promise.
' */
'struct _GDate
'{
'  guint julian_days : 32; /* julian days representation - we use a
'                           *  bitfield hoping that 64 bit platforms
'                           *  will pack this whole struct in one big
'                           *  int
'                           */

'  guint julian : 1;    /* julian is valid */
'  guint dmy    : 1;    /* dmy is valid */

'  /* DMY representation */
'  guint day    : 6;
'  guint month  : 4;
'  guint year   : 16;
'};

TYPE GDate
   julian_days AS BIT * 32 IN DWORD   ' /* julian days representation - we use a
                                      ' *  bitfield hoping that 64 bit platforms
                                      ' *  will pack this whole struct in one big
                                      ' *  int
                                      ' */

   julian      AS BIT * 1 IN DWORD    ' /* julian is valid */
   dmy         AS BIT * 1             ' /* dmy is valid */

   ' /* DMY representation */
   day         AS BIT * 6
   month       AS BIT * 4
   year        AS BIT * 16
END TYPE

'/* g_date_new() returns an invalid date, you then have to _set() stuff
' * to get a usable object. You can also allocate a GDate statically,
' * then call g_date_clear() to initialize.
' */

' ========================================================================================
'GDate*       g_date_new                   (void);
' ========================================================================================
DECLARE FUNCTION g_date_new CDECL LIB $GLIB_DLLNAME ALIAS "g_date_new" ( _
 ) AS DWORD                                 ' GDate*

' ========================================================================================
'GDate*       g_date_new_dmy               (GDateDay     day,
'                                           GDateMonth   month,
'                                           GDateYear    year);
' ========================================================================================
DECLARE FUNCTION g_date_new_dmy CDECL LIB $GLIB_DLLNAME ALIAS "g_date_new_dmy" ( _
   BYVAL BYTE _                             ' GDateDay     day
 , BYVAL BYTE _                             ' GDateMonth   month
 , BYVAL WORD _                             ' GDateYear    year
 ) AS DWORD                                 ' GDate*

' ========================================================================================
'GDate*       g_date_new_julian            (guint32      julian_day);
' ========================================================================================
DECLARE FUNCTION g_date_new_julian CDECL LIB $GLIB_DLLNAME ALIAS "g_date_new_julian" ( _
   BYVAL DWORD _                            ' guint32      julian_day
 ) AS DWORD                                 ' GDate*

' ========================================================================================
'void         g_date_free                  (GDate       *date);
' ========================================================================================
DECLARE SUB g_date_free CDECL LIB $GLIB_DLLNAME ALIAS "g_date_free" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 )                                          ' void

'/* check g_date_valid() after doing an operation that might fail, like
' * _parse.  Almost all g_date operations are undefined on invalid
' * dates (the exceptions are the mutators, since you need those to
' * return to validity).
' */

' ========================================================================================
'gboolean     g_date_valid                 (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_valid CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid" ( _
   BYVAL GDate PTR _                        ' const GDate       *date
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_day             (GDateDay     day) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_day CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_day" ( _
   BYVAL BYTE _                             ' GDateDay     day
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_month           (GDateMonth month) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_month" ( _
   BYVAL BYTE _                             ' GDateMonth   month
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_year            (GDateYear  year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_year" ( _
   BYVAL WORD _                             ' GDateYear   year
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_weekday         (GDateWeekday weekday) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_weekday CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_weekday" ( _
   BYVAL BYTE _                             ' GDateWeekday weekday
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_julian          (guint32 julian_date) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_julian CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_julian" ( _
   BYVAL DWORD _                            ' guint32 julian_date
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_valid_dmy             (GDateDay     day,
'                                           GDateMonth   month,
'                                           GDateYear    year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_valid_dmy CDECL LIB $GLIB_DLLNAME ALIAS "g_date_valid_dmy" ( _
   BYVAL BYTE _                             ' GDateDay     day
 , BYVAL BYTE _                             ' GDateMonth   month
 , BYVAL WORD _                             ' GDateYear    year
 ) AS LONG                                  ' gboolean

' ========================================================================================
'GDateWeekday g_date_get_weekday           (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_weekday CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_weekday" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS BYTE                                  ' GDateWeekday

' ========================================================================================
'GDateMonth   g_date_get_month             (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_month" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS BYTE                                  ' GDateMonth

' ========================================================================================
'GDateYear    g_date_get_year              (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_year" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS WORD                                  ' GDateYear

' ========================================================================================
'GDateDay     g_date_get_day               (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_day CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_day" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS BYTE                                  ' GDateDay

' ========================================================================================
'guint32      g_date_get_julian            (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_julian CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_julian" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS DWORD                                 ' guint32

' ========================================================================================
'guint        g_date_get_day_of_year       (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_day_of_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_day_of_year" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS DWORD                                 ' guint

'/* First monday/sunday is the start of week 1; if we haven't reached
' * that day, return 0. These are not ISO weeks of the year; that
' * routine needs to be added.
' * these functions return the number of weeks, starting on the
' * corrsponding day
' */

' ========================================================================================
'guint        g_date_get_monday_week_of_year (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_monday_week_of_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_monday_week_of_year" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS DWORD                                 ' guint

' ========================================================================================
'guint        g_date_get_sunday_week_of_year (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_sunday_week_of_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_sunday_week_of_year" ( _
   BYVAL GDate PTR _                            ' const GDate *date
 ) AS DWORD                                 ' guint

' ========================================================================================
'guint        g_date_get_iso8601_week_of_year (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_get_iso8601_week_of_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_iso8601_week_of_year" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS DWORD                                 ' guint

'/* If you create a static date struct you need to clear it to get it
' * in a sane state before use. You can clear a whole array at
' * once with the ndates argument.
' */

' ========================================================================================
'void         g_date_clear                 (GDate       *date,
'                                           guint        n_dates);
' ========================================================================================
DECLARE SUB g_date_clear CDECL LIB $GLIB_DLLNAME ALIAS "g_date_clear" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_dates
 )                                          ' void

'/* The parse routine is meant for dates typed in by a user, so it
' * permits many formats but tries to catch common typos. If your data
' * needs to be strictly validated, it is not an appropriate function.
' */

' ========================================================================================
'void         g_date_set_parse             (GDate       *date,
'                                           const gchar *str);
' ========================================================================================
DECLARE SUB g_date_set_parse CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_parse" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYREF ASCIIZ _                           ' const gchar *str
 )                                          ' void

' ========================================================================================
'void         g_date_set_time_t            (GDate       *date,
'                                           time_t       timet);
' ========================================================================================
DECLARE SUB g_date_set_time_t CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_time_t" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL LONG _                             ' time_t       timet
 )                                          ' void

' ========================================================================================
'void         g_date_set_time_val          (GDate       *date,
'                                           GTimeVal    *timeval);
' ========================================================================================
DECLARE SUB g_date_set_time_val CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_time_val" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYREF GTimeVal _                         ' GTimeVal     timeval
 )                                          ' void

'#IF NOT %DEF(%G_DISABLE_DEPRECATED)
'' ========================================================================================
''void         g_date_set_time              (GDate       *date,
''                                           GTime        time_);
'' ========================================================================================
'DECLARE SUB g_date_set_time CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_time" ( _
'   BYVAL GDate PTR _                        ' GDate       *date
' , BYVAL DWORD _                            ' GTime        time_
' )                                          ' void
'#ENDIF

' ========================================================================================
'void         g_date_set_month             (GDate       *date,
'                                           GDateMonth   month);
' ========================================================================================
DECLARE SUB g_date_set_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_month" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL BYTE _                             ' GDateMonth   month
 )                                          ' void

' ========================================================================================
'void         g_date_set_day               (GDate       *date,
'                                           GDateDay     day);
' ========================================================================================
DECLARE SUB g_date_set_day CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_day" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL BYTE _                             ' GDateDay     day
 )                                          ' void

' ========================================================================================
'void         g_date_set_year              (GDate       *date,
'                                           GDateYear    year);
' ========================================================================================
DECLARE SUB g_date_set_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_year" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL WORD _                             ' GDateYear    year
 )                                          ' void

' ========================================================================================
'void         g_date_set_dmy               (GDate       *date,
'                                           GDateDay     day,
'                                           GDateMonth   month,
'                                           GDateYear    y);
' ========================================================================================
DECLARE SUB g_date_set_dmy CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_dmy" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL BYTE _                             ' GDateDay     day
 , BYVAL BYTE _                             ' GDateMonth   month
 , BYVAL WORD _                             ' GDateYear    y
 )                                          ' void

' ========================================================================================
'void         g_date_set_julian            (GDate       *date,
'                                           guint32      julian_date);
' ========================================================================================
DECLARE SUB g_date_set_julian CDECL LIB $GLIB_DLLNAME ALIAS "g_date_set_julian" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint32      julian_date
 )                                          ' void

' ========================================================================================
'gboolean     g_date_is_first_of_month     (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_is_first_of_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_is_first_of_month" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_date_is_last_of_month      (const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_is_last_of_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_is_last_of_month" ( _
   BYVAL GDate PTR _                        ' const GDate *date
 ) AS LONG                                  ' gboolean

'/* To go forward by some number of weeks just go forward weeks*7 days */

' ========================================================================================
'void         g_date_add_days              (GDate       *date,
'                                           guint        n_days);
' ========================================================================================
DECLARE SUB g_date_add_days CDECL LIB $GLIB_DLLNAME ALIAS "g_date_add_days" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_days
 )                                          ' void

' ========================================================================================
'void         g_date_subtract_days         (GDate       *date,
'                                           guint        n_days);
' ========================================================================================
DECLARE SUB g_date_subtract_days CDECL LIB $GLIB_DLLNAME ALIAS "g_date_subtract_days" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_days
 )                                          ' void

'/* If you add/sub months while day > 28, the day might change */

' ========================================================================================
'void         g_date_add_months            (GDate       *date,
'                                           guint        n_months);
' ========================================================================================
DECLARE SUB g_date_add_months CDECL LIB $GLIB_DLLNAME ALIAS "g_date_add_months" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_months
 )                                          ' void

' ========================================================================================
'void         g_date_subtract_months       (GDate       *date,
'                                           guint        n_months);
' ========================================================================================
DECLARE SUB g_date_subtract_months CDECL LIB $GLIB_DLLNAME ALIAS "g_date_subtract_months" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_months
 )                                          ' void

'/* If it's feb 29, changing years can move you to the 28th */

' ========================================================================================
'void         g_date_add_years             (GDate       *date,
'                                           guint        n_years);
' ========================================================================================
DECLARE SUB g_date_add_years CDECL LIB $GLIB_DLLNAME ALIAS "g_date_add_years" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_years
 )                                          ' void

' ========================================================================================
'void         g_date_subtract_years        (GDate       *date,
'                                           guint        n_years);
' ========================================================================================
DECLARE SUB g_date_subtract_years CDECL LIB $GLIB_DLLNAME ALIAS "g_date_subtract_years" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL DWORD _                            ' guint        n_years
 )                                          ' void

' ========================================================================================
'gboolean     g_date_is_leap_year          (GDateYear    year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_is_leap_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_is_leap_year" ( _
   BYVAL WORD _                             ' GDateYear    year
 ) AS LONG                                  ' gboolean

' ========================================================================================
'guint8       g_date_get_days_in_month     (GDateMonth   month,
'                                           GDateYear    year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_get_days_in_month CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_days_in_month" ( _
   BYVAL BYTE _                             ' GDateMonth   month
 , BYVAL WORD _                             ' GDateYear    year
 ) AS BYTE                                  ' guint8

' ========================================================================================
'guint8       g_date_get_monday_weeks_in_year  (GDateYear    year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_get_monday_weeks_in_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_monday_weeks_in_year" ( _
   BYVAL WORD _                             ' GDateYear    year
 ) AS BYTE                                  ' guint8

' ========================================================================================
'guint8       g_date_get_sunday_weeks_in_year  (GDateYear    year) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_date_get_sunday_weeks_in_year CDECL LIB $GLIB_DLLNAME ALIAS "g_date_get_sunday_weeks_in_year" ( _
   BYVAL WORD _                             ' GDateYear    year
 ) AS BYTE                                  ' guint8

'/* Returns the number of days between the two dates.  If date2 comes
'   before date1, a negative value is return. */

' ========================================================================================
'gint         g_date_days_between          (const GDate *date1,
'                                           const GDate *date2);
' ========================================================================================
DECLARE FUNCTION g_date_days_between CDECL LIB $GLIB_DLLNAME ALIAS "g_date_days_between" ( _
   BYVAL GDate PTR _                        ' const GDate *date1
 , BYVAL GDate PTR _                        ' const GDate *date2
 ) AS LONG                                  ' gint

'/* qsort-friendly (with a cast...) */

' ========================================================================================
'gint         g_date_compare               (const GDate *lhs,
'                                           const GDate *rhs);
' ========================================================================================
DECLARE FUNCTION g_date_compare CDECL LIB $GLIB_DLLNAME ALIAS "g_date_compare" ( _
   BYVAL GDate PTR _                        ' const GDate *lhs
 , BYVAL GDate PTR _                        ' const GDate *rhs
 ) AS LONG                                  ' gint

' ========================================================================================
'void         g_date_to_struct_tm          (const GDate *date,
'                                           struct tm   *tm);
' ========================================================================================
DECLARE SUB g_date_to_struct_tm CDECL LIB $GLIB_DLLNAME ALIAS "g_date_to_struct_tm" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYREF tm _                               ' struct tm   *tm
 )                                          ' void

' ========================================================================================
'void         g_date_clamp                 (GDate *date,
'                                           const GDate *min_date,
'                                           const GDate *max_date);
' ========================================================================================
DECLARE SUB g_date_clamp CDECL LIB $GLIB_DLLNAME ALIAS "g_date_clamp" ( _
   BYVAL GDate PTR _                        ' GDate       *date
 , BYVAL GDate PTR _                        ' const GDate *min_date
 , BYVAL GDate PTR _                        ' const GDate *max_date
 )                                          ' void

'/* Swap date1 and date2's values if date1 > date2. */

' ========================================================================================
'void         g_date_order                 (GDate *date1, GDate *date2);
' ========================================================================================
DECLARE SUB g_date_order CDECL LIB $GLIB_DLLNAME ALIAS "g_date_order" ( _
   BYVAL GDate PTR _                        ' GDate *date1
 , BYVAL GDate PTR _                        ' GDate *date2
 )                                          ' void

'/* Just like strftime() except you can only use date-related formats.
' *   Using a time format is undefined.
' */

' ========================================================================================
'gsize        g_date_strftime              (gchar       *s,
'                                           gsize        slen,
'                                           const gchar *format,
'                                           const GDate *date);
' ========================================================================================
DECLARE FUNCTION g_date_strftime CDECL LIB $GLIB_DLLNAME ALIAS "g_date_strftime" ( _
   BYREF ASCIIZ _                             ' gchar       *s
 , BYVAL DWORD _                              ' gsize        slen
 , BYREF ASCIIZ _                             ' const gchar *format
 , BYVAL GDate PTR _                          ' const GDate *date
 ) AS DWORD                                   ' gsize

'#ifndef G_DISABLE_DEPRECATED

'#define g_date_weekday                g_date_get_weekday
'#define g_date_month                  g_date_get_month
'#define g_date_year                   g_date_get_year
'#define g_date_day                    g_date_get_day
'#define g_date_julian                 g_date_get_julian
'#define g_date_day_of_year            g_date_get_day_of_year
'#define g_date_monday_week_of_year    g_date_get_monday_week_of_year
'#define g_date_sunday_week_of_year    g_date_get_sunday_week_of_year
'#define g_date_days_in_month          g_date_get_days_in_month
'#define g_date_monday_weeks_in_year   g_date_get_monday_weeks_in_year
'#define g_date_sunday_weeks_in_year   g_date_get_sunday_weeks_in_year

'#endif /* G_DISABLE_DEPRECATED */

'G_END_DECLS

'#endif /* __G_DATE_H__ */
#ENDIF   ' /* __GDATE_INC__ */
