'/* gfileutils.h - File utility functions
' *
' *  Copyright 2000 Red Hat, Inc.
' *
' * GLib is free software; you can redistribute it and/or modify it
' * under the terms of the GNU Lesser General Public License as
' * published by the Free Software Foundation; either version 2 of the
' * License, or (at your option) any later version.
' *
' * GLib is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with GLib; see the file COPYING.LIB.  If not,
' * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' *   Boston, MA 02111-1307, USA.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_FILEUTILS_H__
'#define __G_FILEUTILS_H__

#IF NOT %DEF(%GFILEUTILS_INC)
    %GFILEUTILS_INC = 1

#INCLUDE ONCE "gerror.inc"

'G_BEGIN_DECLS

'#define G_FILE_ERROR g_file_error_quark ()

'typedef enum
'{
'  G_FILE_ERROR_EXIST,
'  G_FILE_ERROR_ISDIR,
'  G_FILE_ERROR_ACCES,
'  G_FILE_ERROR_NAMETOOLONG,
'  G_FILE_ERROR_NOENT,
'  G_FILE_ERROR_NOTDIR,
'  G_FILE_ERROR_NXIO,
'  G_FILE_ERROR_NODEV,
'  G_FILE_ERROR_ROFS,
'  G_FILE_ERROR_TXTBSY,
'  G_FILE_ERROR_FAULT,
'  G_FILE_ERROR_LOOP,
'  G_FILE_ERROR_NOSPC,
'  G_FILE_ERROR_NOMEM,
'  G_FILE_ERROR_MFILE,
'  G_FILE_ERROR_NFILE,
'  G_FILE_ERROR_BADF,
'  G_FILE_ERROR_INVAL,
'  G_FILE_ERROR_PIPE,
'  G_FILE_ERROR_AGAIN,
'  G_FILE_ERROR_INTR,
'  G_FILE_ERROR_IO,
'  G_FILE_ERROR_PERM,
'  G_FILE_ERROR_NOSYS,
'  G_FILE_ERROR_FAILED
'} GFileError;

%G_FILE_ERROR_EXIST       = 0
%G_FILE_ERROR_ISDIR       = 1
%G_FILE_ERROR_ACCES       = 2
%G_FILE_ERROR_NAMETOOLONG = 3
%G_FILE_ERROR_NOENT       = 4
%G_FILE_ERROR_NOTDIR      = 5
%G_FILE_ERROR_NXIO        = 6
%G_FILE_ERROR_NODEV       = 7
%G_FILE_ERROR_ROFS        = 8
%G_FILE_ERROR_TXTBSY      = 9
%G_FILE_ERROR_FAULT       = 10
%G_FILE_ERROR_LOOP        = 11
%G_FILE_ERROR_NOSPC       = 12
%G_FILE_ERROR_NOMEM       = 13
%G_FILE_ERROR_MFILE       = 14
%G_FILE_ERROR_NFILE       = 15
%G_FILE_ERROR_BADF        = 16
%G_FILE_ERROR_INVAL       = 17
%G_FILE_ERROR_PIPE        = 18
%G_FILE_ERROR_AGAIN       = 19
%G_FILE_ERROR_INTR        = 20
%G_FILE_ERROR_IO          = 21
%G_FILE_ERROR_PERM        = 22
%G_FILE_ERROR_NOSYS       = 23
%G_FILE_ERROR_FAILED      = 24

'/* For backward-compat reasons, these are synced to an old
' * anonymous enum in libgnome. But don't use that enum
' * in new code.
' */
'typedef enum
'{
'  G_FILE_TEST_IS_REGULAR    = 1 << 0,
'  G_FILE_TEST_IS_SYMLINK    = 1 << 1,
'  G_FILE_TEST_IS_DIR        = 1 << 2,
'  G_FILE_TEST_IS_EXECUTABLE = 1 << 3,
'  G_FILE_TEST_EXISTS        = 1 << 4
'} GFileTest;

%G_FILE_TEST_IS_REGULAR    = &H1
%G_FILE_TEST_IS_SYMLINK    = &H2
%G_FILE_TEST_IS_DIR        = &H4
%G_FILE_TEST_IS_EXECUTABLE = &H8
%G_FILE_TEST_EXISTS        = &H10

' ========================================================================================
'GQuark     g_file_error_quark      (void);
' ========================================================================================
DECLARE FUNCTION g_file_error_quark CDECL LIB $GLIB_DLLNAME ALIAS "g_file_error_quark" ( _
 ) AS DWORD                                 ' GQuark

DECLARE FUNCTION G_FILE_ERROR CDECL LIB $GLIB_DLLNAME ALIAS "g_file_error_quark" ( _
 ) AS DWORD                                 ' GQuark

'/* So other code can generate a GFileError */

' ========================================================================================
'GFileError g_file_error_from_errno (gint err_no);
' ========================================================================================
DECLARE FUNCTION g_file_error_from_errno CDECL LIB $GLIB_DLLNAME ALIAS "g_file_error_from_errno" ( _
   BYVAL LONG _                             ' gint err_no
 ) AS DWORD                                 ' GFileError

'#ifdef G_OS_WIN32
'#define g_file_test g_file_test_utf8
'#define g_file_get_contents g_file_get_contents_utf8
'#define g_mkstemp g_mkstemp_utf8
'#define g_file_open_tmp g_file_open_tmp_utf8
'#endif

' ========================================================================================
'gboolean g_file_test         (const gchar  *filename,
'                              GFileTest     test);
' ========================================================================================
DECLARE FUNCTION g_file_test CDECL LIB $GLIB_DLLNAME ALIAS "g_file_test" ( _
   BYREF ASCIIZ _                           ' const gchar  *filename
 , BYVAL LONG _                             ' GFileTest     test
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_file_get_contents (const gchar  *filename,
'                              gchar       **contents,
'                              gsize        *length,
'                              GError      **error);
' ========================================================================================
DECLARE FUNCTION g_file_get_contents CDECL LIB $GLIB_DLLNAME ALIAS "g_file_get_contents" ( _
   BYREF ASCIIZ _                           ' const gchar  *filename
 , BYREF ANY _                              ' gchar       **contents
 , BYREF DWORD _                            ' gsize        *length
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_file_set_contents (const gchar *filename,
'                              const gchar *contents,
'                              gssize        length,
'                              GError      **error);
' ========================================================================================
DECLARE FUNCTION g_file_set_contents CDECL LIB $GLIB_DLLNAME ALIAS "g_file_set_contents" ( _
   BYREF ASCIIZ _                           ' const gchar  *filename
 , BYREF ANY _                              ' const gchar  *contents
 , BYVAL LONG _                             ' gssize        length
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gchar   *g_file_read_link    (const gchar  *filename,
'                              GError      **error);
' ========================================================================================
DECLARE FUNCTION g_file_read_link CDECL LIB $GLIB_DLLNAME ALIAS "g_file_read_link" ( _
   BYREF ASCIIZ _                           ' const gchar  *filename
 , BYREF DWORD _                            ' GError      **error
 ) AS DWORD                                 ' gchar*

'/* Wrapper / workalike for mkstemp() */

' ========================================================================================
'gint    g_mkstemp            (gchar        *tmpl);
' ========================================================================================
DECLARE FUNCTION g_mkstemp CDECL LIB $GLIB_DLLNAME ALIAS "g_mkstemp" ( _
   BYREF ASCIIZ _                           ' gchar        *tmpl
 ) AS LONG                                  ' gint

'/* Wrapper for g_mkstemp */
' ========================================================================================
'gint    g_file_open_tmp      (const gchar  *tmpl,
'                              gchar       **name_used,
'                              GError      **error);
' ========================================================================================
DECLARE FUNCTION g_file_open_tmp CDECL LIB $GLIB_DLLNAME ALIAS "g_file_open_tmp" ( _
   BYREF ASCIIZ _                           ' gchar        *tmpl
 , BYREF ANY _                              ' gchar       **name_used
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' gint

' ========================================================================================
'char *g_format_size_for_display (goffset size);
' ========================================================================================
DECLARE FUNCTION g_format_size_for_display CDECL LIB $GLIB_DLLNAME ALIAS "g_format_size_for_display" ( _
   BYVAL QUAD _                             ' goffset size
 ) AS DWORD                                 ' char*

' ========================================================================================
'gchar *g_build_path     (const gchar *separator,
'                         const gchar *first_element,
'                         ...) G_GNUC_MALLOC G_GNUC_NULL_TERMINATED;
' ========================================================================================
DECLARE FUNCTION g_build_path CDECL LIB $GLIB_DLLNAME ALIAS "g_build_path" ( _
   BYREF ASCIIZ _                           ' const gchar *separator
 , BYREF ASCIIZ _                           ' const gchar *first_element
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_build_pathv    (const gchar  *separator,
'                         gchar       **args) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_build_pathv CDECL LIB $GLIB_DLLNAME ALIAS "g_build_pathv" ( _
   BYREF ASCIIZ _                           ' const gchar *separator
 , BYREF ASCIIZ _                           ' gchar       **args
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_build_filename (const gchar *first_element,
'                         ...) G_GNUC_MALLOC G_GNUC_NULL_TERMINATED;
' ========================================================================================
DECLARE FUNCTION g_build_filename CDECL LIB $GLIB_DLLNAME ALIAS "g_build_filename" ( _
   BYREF ASCIIZ _                           ' const gchar *first_element
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 , OPTIONAL ANY _
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_build_filenamev (gchar      **args) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_build_filenamev CDECL LIB $GLIB_DLLNAME ALIAS "g_build_filenamev" ( _
   BYREF ASCIIZ _                           ' gchar       **args
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'int    g_mkdir_with_parents (const gchar *pathname,
'                             int          mode);
' ========================================================================================
DECLARE FUNCTION g_mkdir_with_parents CDECL LIB $GLIB_DLLNAME ALIAS "g_mkdir_with_parents" ( _
   BYREF ASCIIZ _                           ' const gchar *pathname
 , BYVAL LONG _                             ' int          mode
 ) AS LONG                                  ' int

'G_END_DECLS

'#endif /* __G_FILEUTILS_H__ */
#ENDIF   ' /* __GFILEUTILS_INC__ */
