'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_HOOK_H__
'#define __G_HOOK_H__

#IF NOT %DEF(%GHOOK_INC)
    %GHOOK_INC = 1

#INCLUDE ONCE "gmem.inc"

'G_BEGIN_DECLS


'/* --- typedefs --- */
'typedef struct _GHook      GHook;
'typedef struct _GHookList   GHookList;

'typedef gint      (*GHookCompareFunc)   (GHook      *new_hook,
'                   GHook      *sibling);
'FUNCTION GHookCompareFunc (BYVAL new_hook AS GHook PTR, BYVAL sibling AS GHook PTR) AS LONG

'typedef gboolean   (*GHookFindFunc)   (GHook      *hook,
'                   gpointer    data);
'FUNCTION GHookFindFunc (BYVAL hook AS GHook PTR, BYVAL pdata AS DWORD) AS LONG

'typedef void      (*GHookMarshaller)   (GHook      *hook,
'                   gpointer    marshal_data);
'SUB GHookMarshaller (BYVAL hook AS GHook PTR, BYVAL marshal_data AS DWORD)

'typedef gboolean   (*GHookCheckMarshaller)   (GHook      *hook,
'                   gpointer    marshal_data);
'FUNCTION GHookCheckMarshaller (BYVAL hook AS GHook PTR, BYVAL marshal_data AS DWORD) AS LONG

'typedef void      (*GHookFunc)      (gpointer    data);
'SUB GHookFunc (BYVAL pdata AS DWORD)

'typedef gboolean   (*GHookCheckFunc)   (gpointer    data);
'FUNCTION GHookCheckFunc (BYVAL pdata AS DWORD) AS LONG

'typedef void      (*GHookFinalizeFunc)   (GHookList      *hook_list,
'                   GHook          *hook);
'SUB GHookFinalizeFunc (BYVAL hook_list AS GHookList PTR, BYVAL hook AS GHook PTR)

'typedef enum
'{
'  G_HOOK_FLAG_ACTIVE     = 1 << 0,
'  G_HOOK_FLAG_IN_CALL    = 1 << 1,
'  G_HOOK_FLAG_MASK       = 0x0f
'} GHookFlagMask;

%G_HOOK_FLAG_ACTIVE     = &H1
%G_HOOK_FLAG_IN_CALL    = &H2
%G_HOOK_FLAG_MASK       = &H0f

'#define G_HOOK_FLAG_USER_SHIFT   (4)
%G_HOOK_FLAG_USER_SHIFT = 4

'/* --- structures --- */
'struct _GHookList
'{
'  gulong       seq_id;
'  guint          hook_size : 16;
'  guint          is_setup : 1;
'  GHook         *hooks;
'  gpointer       dummy3;
'  GHookFinalizeFunc finalize_hook;
'  gpointer       dummy[2];
'};

'struct _GHook
'{
'  gpointer    data;
'  GHook      *next;
'  GHook      *prev;
'  guint       ref_count;
'  gulong    hook_id;
'  guint       flags;
'  gpointer    func;
'  GDestroyNotify destroy;
'};

TYPE GHook
   data      AS DWORD
   next      AS GHook PTR
   prev      AS GHook PTR
   ref_count AS DWORD
   hook_id   AS DWORD
   flags     AS DWORD
   func      AS DWORD
   destroy   AS DWORD
END TYPE

TYPE GHookList
   seq_id        AS DWORD
   hook_size     AS BIT * 16 IN DWORD
   is_setup      AS BIT * 1
   hooks         AS GHook PTR
   dummy3        AS DWORD
   finalize_hook AS DWORD
   dummy(1)      AS DWORD
END TYPE

'/* --- macros --- */
'#define   G_HOOK(hook)         ((GHook*) (hook))

' ========================================================================================
'#define   G_HOOK_FLAGS(hook)      (G_HOOK (hook)->flags)
' ========================================================================================
MACRO G_HOOK_FLAGS(hook) = @hook.flags

' ========================================================================================
'#define   G_HOOK_ACTIVE(hook)      ((G_HOOK_FLAGS (hook) & \
'                 G_HOOK_FLAG_ACTIVE) != 0)
' ========================================================================================
MACRO G_HOOK_ACTIVE(hook) = ((G_HOOK_FLAGS (hook) AND %G_HOOK_FLAG_ACTIVE) <> 0)

' ========================================================================================
'#define   G_HOOK_IN_CALL(hook)      ((G_HOOK_FLAGS (hook) & \
'                 G_HOOK_FLAG_IN_CALL) != 0)
' ========================================================================================
MACRO G_HOOK_IN_CALL(hook) = ((G_HOOK_FLAGS (hook) AND %G_HOOK_FLAG_IN_CALL) <> 0)

' ========================================================================================
'#define G_HOOK_IS_VALID(hook)      (G_HOOK (hook)->hook_id != 0 && \
'                                   (G_HOOK_FLAGS (hook) & \
'                                    G_HOOK_FLAG_ACTIVE))
' ========================================================================================
MACRO G_HOOK_IS_VALID(hook) = (@hook.hook_id <> 0 AND (G_HOOK_FLAGS (hook) AND %G_HOOK_FLAG_ACTIVE))

' ========================================================================================
'#define G_HOOK_IS_UNLINKED(hook)   (G_HOOK (hook)->next == NULL && \
'                G_HOOK (hook)->prev == NULL && \
'                G_HOOK (hook)->hook_id == 0 && \
'                G_HOOK (hook)->ref_count == 0)
' ========================================================================================
MACRO G_HOOK_IS_UNLINKED(hook) = (@hook.next = %NULL AND @hook.prev = %NULL AND @hook.hook_id = 0 AND @hook.ref_count = 0)


'/* --- prototypes --- */
'/* callback maintenance functions */

' ========================================================================================
'void    g_hook_list_init      (GHookList      *hook_list,
'                               guint           hook_size);
' ========================================================================================
DECLARE SUB g_hook_list_init CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_init" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL DWORD _                            ' guint           hook_size
 )                                          ' void

' ========================================================================================
'void    g_hook_list_clear      (GHookList      *hook_list);
' ========================================================================================
DECLARE SUB g_hook_list_clear CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_clear" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 )                                          ' void

' ========================================================================================
'GHook*    g_hook_alloc         (GHookList      *hook_list);
' ========================================================================================
DECLARE FUNCTION g_hook_alloc CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_alloc" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'void    g_hook_free         (GHookList      *hook_list,
'                             GHook          *hook);
' ========================================================================================
DECLARE SUB g_hook_free CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_free" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 )                                          ' void

' ========================================================================================
'GHook *    g_hook_ref         (GHookList      *hook_list,
'                               GHook          *hook);
' ========================================================================================
DECLARE FUNCTION g_hook_ref CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_ref" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'void    g_hook_unref         (GHookList      *hook_list,
'                              GHook          *hook);
' ========================================================================================
DECLARE SUB g_hook_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_unref" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 )                                          ' void

' ========================================================================================
'gboolean g_hook_destroy         (GHookList      *hook_list,
'                                 gulong          hook_id);
' ========================================================================================
DECLARE FUNCTION g_hook_destroy CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_destroy" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL DWORD _                            ' gulong          hook_id
 ) AS LONG                                  ' gboolean

' ========================================================================================
'void    g_hook_destroy_link      (GHookList      *hook_list,
'                                  GHook          *hook);
' ========================================================================================
DECLARE SUB g_hook_destroy_link CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_destroy_link" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 )                                          ' void

' ========================================================================================
'void    g_hook_prepend         (GHookList      *hook_list,
'                                GHook          *hook);
' ========================================================================================
DECLARE SUB g_hook_prepend CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_prepend" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 )                                          ' void

' ========================================================================================
'void    g_hook_insert_before      (GHookList      *hook_list,
'                                   GHook          *sibling,
'                                   GHook          *hook);
' ========================================================================================
DECLARE SUB g_hook_insert_before CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_insert_before" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *sibling
 , BYVAL GHook PTR _                        ' GHook          *hook
 )                                          ' void

' ========================================================================================
'void    g_hook_insert_sorted      (GHookList        *hook_list,
'                                   GHook            *hook,
'                                   GHookCompareFunc  func);
' ========================================================================================
DECLARE SUB g_hook_insert_sorted CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_insert_sorted" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 , BYVAL DWORD _                            ' GHookCompareFunc  func
 )                                          ' void

' ========================================================================================
'GHook*    g_hook_get         (GHookList      *hook_list,
'                              gulong          hook_id);
' ========================================================================================
DECLARE FUNCTION g_hook_get CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_get" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL DWORD _                            ' gulong          hook_id
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'GHook*    g_hook_find         (GHookList      *hook_list,
'                               gboolean        need_valids,
'                               GHookFindFunc   func,
'                               gpointer        data);
' ========================================================================================
DECLARE FUNCTION g_hook_find CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_find" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        need_valids
 , BYVAL DWORD _                            ' GHookFindFunc   func
 , BYVAL DWORD _                            ' gpointer        data
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'GHook*    g_hook_find_data      (GHookList      *hook_list,
'                                 gboolean        need_valids,
'                                 gpointer        data);
' ========================================================================================
DECLARE FUNCTION g_hook_find_data CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_find_data" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        need_valids
 , BYVAL DWORD _                            ' gpointer        data
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'GHook*    g_hook_find_func      (GHookList      *hook_list,
'                                 gboolean        need_valids,
'                                 gpointer        func);
' ========================================================================================
DECLARE FUNCTION g_hook_find_func CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_find_func" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        need_valids
 , BYVAL DWORD _                            ' gpointer        func
 ) AS DWORD                                 ' GHook*

' ========================================================================================
'GHook*    g_hook_find_func_data      (GHookList      *hook_list,
'                                      gboolean        need_valids,
'                                      gpointer        func,
'                                      gpointer        data);
' ========================================================================================
DECLARE FUNCTION g_hook_find_func_data CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_find_func_data" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        need_valids
 , BYVAL DWORD _                            ' gpointer        func
 , BYVAL DWORD _                            ' gpointer        data
 ) AS DWORD                                 ' GHook*

'/* return the first valid hook, and increment its reference count */

' ========================================================================================
'GHook*    g_hook_first_valid      (GHookList      *hook_list,
'                                   gboolean        may_be_in_call);
' ========================================================================================
DECLARE FUNCTION g_hook_first_valid CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_first_valid" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        may_be_in_call
 ) AS DWORD                                 ' GHook*

'/* return the next valid hook with incremented reference count, and
' * decrement the reference count of the original hook
' */

' ========================================================================================
'GHook*    g_hook_next_valid      (GHookList      *hook_list,
'                                  GHook          *hook,
'                                  gboolean        may_be_in_call);
' ========================================================================================
DECLARE FUNCTION g_hook_next_valid CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_next_valid" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL GHook PTR _                        ' GHook          *hook
 , BYVAL LONG _                             ' gboolean        may_be_in_call
 ) AS DWORD                                 ' GHook*

'/* GHookCompareFunc implementation to insert hooks sorted by their id */

' ========================================================================================
'gint    g_hook_compare_ids      (GHook         *new_hook,
'                                 GHook         *sibling);
' ========================================================================================
DECLARE FUNCTION g_hook_compare_ids CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_compare_ids" ( _
   BYVAL GHook PTR _                        ' GHook          *new_hook
 , BYVAL GHook PTR _                        ' GHook          *sibling
 ) AS LONG                                  ' int

'/* convenience macros */

' ========================================================================================
'#define    g_hook_append( hook_list, hook )  \
'     g_hook_insert_before ((hook_list), NULL, (hook))
' ========================================================================================
MACRO g_hook_append(hook_list, hook) = g_hook_insert_before (hook_list, %NULL, hook)

'/* invoke all valid hooks with the (*GHookFunc) signature.
' */

' ========================================================================================
'void    g_hook_list_invoke      (GHookList      *hook_list,
'                                 gboolean        may_recurse);
' ========================================================================================
DECLARE SUB g_hook_list_invoke CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_invoke" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        may_recurse
 )                                          ' void

'/* invoke all valid hooks with the (*GHookCheckFunc) signature,
' * and destroy the hook if FALSE is returned.
' */

' ========================================================================================
'void    g_hook_list_invoke_check   (GHookList      *hook_list,
'                                    gboolean        may_recurse);
' ========================================================================================
DECLARE SUB g_hook_list_invoke_check CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_invoke_check" ( _
   BYVAL GHookList PTR _                    ' GHookList      *hook_list
 , BYVAL LONG _                             ' gboolean        may_recurse
 )                                          ' void

'/* invoke a marshaller on all valid hooks.
' */

' ========================================================================================
'void    g_hook_list_marshal      (GHookList       *hook_list,
'                                  gboolean         may_recurse,
'                                  GHookMarshaller  marshaller,
'                                  gpointer         marshal_data);
' ========================================================================================
DECLARE SUB g_hook_list_marshal CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_marshal" ( _
   BYVAL GHookList PTR _                    ' GHookList       *hook_list
 , BYVAL LONG _                             ' gboolean         may_recurse
 , BYVAL DWORD _                            ' GHookMarshaller  marshaller
 , BYVAL DWORD _                            ' gpointer         marshal_data
 )                                          ' void

' ========================================================================================
'void    g_hook_list_marshal_check   (GHookList            *hook_list,
'                                     gboolean              may_recurse,
'                                     GHookCheckMarshaller  marshaller,
'                                     gpointer              marshal_data);
' ========================================================================================
DECLARE SUB g_hook_list_marshal_check CDECL LIB $GLIB_DLLNAME ALIAS "g_hook_list_marshal_check" ( _
   BYVAL GHookList PTR _                    ' GHookList       *hook_list
 , BYVAL LONG _                             ' gboolean         may_recurse
 , BYVAL DWORD _                            ' GHookMarshaller  marshaller
 , BYVAL DWORD _                            ' gpointer         marshal_data
 )                                          ' void

'G_END_DECLS

'#endif /* __G_HOOK_H__ */
#ENDIF   ' /* __GHOOK_INC__ */
