'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_IOCHANNEL_H__
'#define __G_IOCHANNEL_H__

#IF NOT %DEF(%GIOCHANNEL_INC)
    %GIOCHANNEL_INC = 1

#INCLUDE ONCE "gconvert.inc"
'#INCLUDE ONCE "gmain.inc"
#INCLUDE ONCE "gstring.inc"

'G_BEGIN_DECLS

'/* GIOChannel
' */

'typedef struct _GIOChannel   GIOChannel;
'typedef struct _GIOFuncs        GIOFuncs;

'typedef enum
'{
'  G_IO_ERROR_NONE,
'  G_IO_ERROR_AGAIN,
'  G_IO_ERROR_INVAL,
'  G_IO_ERROR_UNKNOWN
'} GIOError;

%G_IO_ERROR_NONE    = 0
%G_IO_ERROR_AGAIN   = 1
%G_IO_ERROR_INVAL   = 2
%G_IO_ERROR_UNKNOWN = 3

'#define G_IO_CHANNEL_ERROR g_io_channel_error_quark()

'typedef enum
'{
'  /* Derived from errno */
'  G_IO_CHANNEL_ERROR_FBIG,
'  G_IO_CHANNEL_ERROR_INVAL,
'  G_IO_CHANNEL_ERROR_IO,
'  G_IO_CHANNEL_ERROR_ISDIR,
'  G_IO_CHANNEL_ERROR_NOSPC,
'  G_IO_CHANNEL_ERROR_NXIO,
'  G_IO_CHANNEL_ERROR_OVERFLOW,
'  G_IO_CHANNEL_ERROR_PIPE,
'  /* Other */
'  G_IO_CHANNEL_ERROR_FAILED
'} GIOChannelError;

'/* Derived from errno */
%G_IO_CHANNEL_ERROR_FBIG     = 0
%G_IO_CHANNEL_ERROR_INVAL    = 1
%G_IO_CHANNEL_ERROR_IO       = 2
%G_IO_CHANNEL_ERROR_ISDIR    = 3
%G_IO_CHANNEL_ERROR_NOSPC    = 4
%G_IO_CHANNEL_ERROR_NXIO     = 5
%G_IO_CHANNEL_ERROR_OVERFLOW = 6
%G_IO_CHANNEL_ERROR_PIPE     = 7
'/* Other */
%G_IO_CHANNEL_ERROR_FAILED   = 8

'typedef enum
'{
'  G_IO_STATUS_ERROR,
'  G_IO_STATUS_NORMAL,
'  G_IO_STATUS_EOF,
'  G_IO_STATUS_AGAIN
'} GIOStatus;

%G_IO_STATUS_ERROR  = 0
%G_IO_STATUS_NORMAL = 1
%G_IO_STATUS_EOF    = 2
%G_IO_STATUS_AGAIN  = 3

'typedef enum
'{
'  G_SEEK_CUR,
'  G_SEEK_SET,
'  G_SEEK_END
'} GSeekType;

%G_SEEK_CUR = 0
%G_SEEK_SET = 1
%G_SEEK_END = 2

'typedef enum
'{
'  G_IO_IN   GLIB_SYSDEF_POLLIN,
'  G_IO_OUT   GLIB_SYSDEF_POLLOUT,
'  G_IO_PRI   GLIB_SYSDEF_POLLPRI,
'  G_IO_ERR   GLIB_SYSDEF_POLLERR,
'  G_IO_HUP   GLIB_SYSDEF_POLLHUP,
'  G_IO_NVAL   GLIB_SYSDEF_POLLNVAL
'} GIOCondition;

%G_IO_IN   = %GLIB_SYSDEF_POLLIN
%G_IO_OUT  = %GLIB_SYSDEF_POLLOUT
%G_IO_PRI  = %GLIB_SYSDEF_POLLPRI
%G_IO_ERR  = %GLIB_SYSDEF_POLLERR
%G_IO_HUP  = %GLIB_SYSDEF_POLLHUP
%G_IO_NVAL = %GLIB_SYSDEF_POLLNVAL

'typedef enum
'{
'  G_IO_FLAG_APPEND = 1 << 0,
'  G_IO_FLAG_NONBLOCK = 1 << 1,
'  G_IO_FLAG_IS_READABLE = 1 << 2,   /* Read only flag */
'  G_IO_FLAG_IS_WRITEABLE = 1 << 3,   /* Read only flag */
'  G_IO_FLAG_IS_SEEKABLE = 1 << 4,   /* Read only flag */
'  G_IO_FLAG_MASK = (1 << 5) - 1,
'  G_IO_FLAG_GET_MASK = G_IO_FLAG_MASK,
'  G_IO_FLAG_SET_MASK = G_IO_FLAG_APPEND | G_IO_FLAG_NONBLOCK
'} GIOFlags;

%G_IO_FLAG_APPEND       = &H1
%G_IO_FLAG_NONBLOCK     = &H2
%G_IO_FLAG_IS_READABLE  = &H4
%G_IO_FLAG_IS_WRITEABLE = &H8
%G_IO_FLAG_IS_SEEKABLE  = &H10
%G_IO_FLAG_MASK         = &H20              -  1
%G_IO_FLAG_GET_MASK     = %G_IO_FLAG_MASK
%G_IO_FLAG_SET_MASK     = %G_IO_FLAG_APPEND OR %G_IO_FLAG_NONBLOCK

'struct _GIOChannel
'{
'  /*< private >*/
'  gint ref_count;
'  GIOFuncs *funcs;

'  gchar *encoding;
'  GIConv read_cd;
'  GIConv write_cd;
'  gchar *line_term;      /* String which indicates the end of a line of text */
'  guint line_term_len;      /* So we can have null in the line term */

'  gsize buf_size;
'  GString *read_buf;      /* Raw data from the channel */
'  GString *encoded_read_buf;    /* Channel data converted to UTF-8 */
'  GString *write_buf;      /* Data ready to be written to the file */
'  gchar partial_write_buf[6];   /* UTF-8 partial characters, null terminated */

'  /* Group the flags together, immediately after partial_write_buf, to save memory */

'  guint use_buffer     : 1;   /* The encoding uses the buffers */
'  guint do_encode      : 1;   /* The encoding uses the GIConv coverters */
'  guint close_on_unref : 1;   /* Close the channel on final unref */
'  guint is_readable    : 1;   /* Cached GIOFlag */
'  guint is_writeable   : 1;   /* ditto */
'  guint is_seekable    : 1;   /* ditto */

'  gpointer reserved1;
'  gpointer reserved2;
'};

TYPE GIOFuncs
   io_read         AS DWORD
   io_write        AS DWORD
   io_seek         AS DWORD
   io_close        AS DWORD
   io_create_watch AS DWORD
   io_free         AS DWORD
   io_set_flags    AS DWORD
   io_get_flags    AS DWORD
END TYPE

TYPE GIOChannel
   ref_count         AS LONG
   funcs             AS GIOFuncs PTR
   encoding          AS ASCIIZ PTR
   read_cd           AS DWORD
   write_cd          AS DWORD
   line_term         AS ASCIIZ PTR
   line_term_len     AS DWORD
   buf_size          AS DWORD
   read_buf          AS GString PTR
   encoded_read_buf  AS GString PTR
   write_buf         AS GString PTR
   partial_write_buf AS STRING * 6
   ' /* Group the flags together, immediately after partial_write_buf, to save memory */
   use_buffer        AS BIT * 1 IN DWORD
   do_encode         AS BIT * 1
   close_on_unref    AS BIT * 1
   is_readable       AS BIT * 1
   is_writeable      AS BIT * 1
   is_seekable       AS BIT * 1
   reserved1         AS DWORD
   reserved2         AS DWORD
END TYPE

'typedef gboolean (*GIOFunc) (GIOChannel   *source,
'              GIOCondition  condition,
'              gpointer      data);
'FUNCTION GIOFunc (BYVAL src AS GIOChannel PTR, BYVAL condition AS LONG, BYVAL pdata AS DWORD) AS LONG

'struct _GIOFuncs
'{
'  GIOStatus (*io_read)           (GIOChannel   *channel,
'                   gchar        *buf,
'              gsize         count,
'              gsize        *bytes_read,
'              GError      **err);
'  GIOStatus (*io_write)          (GIOChannel   *channel,
'              const gchar  *buf,
'              gsize         count,
'              gsize        *bytes_written,
'              GError      **err);
'  GIOStatus (*io_seek)           (GIOChannel   *channel,
'              gint64        offset,
'              GSeekType     type,
'              GError      **err);
'  GIOStatus  (*io_close)         (GIOChannel   *channel,
'              GError      **err);
'  GSource*   (*io_create_watch)  (GIOChannel   *channel,
'              GIOCondition  condition);
'  void       (*io_free)          (GIOChannel   *channel);
'  GIOStatus  (*io_set_flags)     (GIOChannel   *channel,
'                                  GIOFlags      flags,
'              GError      **err);
'  GIOFlags   (*io_get_flags)     (GIOChannel   *channel);
'};

' ========================================================================================
'void        g_io_channel_init   (GIOChannel    *channel);
' ========================================================================================
DECLARE SUB g_io_channel_init CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_init" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
 )                                          ' void

' ========================================================================================
'GIOChannel *g_io_channel_ref    (GIOChannel    *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_ref CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_ref" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
 ) AS DWORD                                 ' GIOChannel*

' ========================================================================================
'void        g_io_channel_unref  (GIOChannel    *channel);
' ========================================================================================
DECLARE SUB g_io_channel_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_unref" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
 )                                          ' void

'#ifndef G_DISABLE_DEPRECATED
' ========================================================================================
'GIOError    g_io_channel_read   (GIOChannel    *channel,
'                                 gchar         *buf,
'                                 gsize          count,
'                                 gsize         *bytes_read);
' ========================================================================================
'DECLARE FUNCTION g_io_channel_read CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read" ( _
'   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
' , BYREF ASCIIZ _                           ' gchar         *buf
' , BYVAL DWORD _                            ' gsize          count
' , BYREF DWORD _                            ' gsize         *bytes_read
' ) AS LONG                                  ' GIOError

' ========================================================================================
'GIOError  g_io_channel_write    (GIOChannel    *channel,
'                                 const gchar   *buf,
'                                 gsize          count,
'                                 gsize         *bytes_written);
' ========================================================================================
'DECLARE FUNCTION g_io_channel_write CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_write" ( _
'   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
' , BYREF ASCIIZ _                           ' gchar         *buf
' , BYVAL DWORD _                            ' gsize          count
' , BYREF DWORD _                            ' gsize         *bytes_written
' ) AS LONG                                  ' GIOError

' ========================================================================================
'GIOError  g_io_channel_seek     (GIOChannel    *channel,
'                                 gint64         offset,
'                                 GSeekType      type);
' ========================================================================================
'DECLARE FUNCTION g_io_channel_seek CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_seek" ( _
'   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
' , BYVAL QUAD _                             ' gint64         offset
' , BYVAL LONG _                             ' GSeekType      type
' ) AS LONG                                  ' GIOError

' ========================================================================================
'void      g_io_channel_close    (GIOChannel    *channel);
' ========================================================================================
'DECLARE SUB g_io_channel_close CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_close" ( _
'   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
' )                                          ' void
'#endif /* G_DISABLE_DEPRECATED */

' ========================================================================================
'GIOStatus g_io_channel_shutdown (GIOChannel      *channel,
'                                 gboolean         flush,
'                                 GError         **err);
' ========================================================================================
DECLARE FUNCTION g_io_channel_shutdown CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_shutdown" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel    *channel
 , BYVAL LONG _                             ' gboolean       flush
 , BYREF DWORD _                            ' GError       **err
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'guint     g_io_add_watch_full   (GIOChannel      *channel,
'                                 gint             priority,
'                                 GIOCondition     condition,
'                                 GIOFunc          func,
'                                 gpointer         user_data,
'                                 GDestroyNotify   notify);
' ========================================================================================
DECLARE FUNCTION g_io_add_watch_full CDECL LIB $GLIB_DLLNAME ALIAS "g_io_add_watch_full" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL LONG _                             ' gint             priority
 , BYVAL LONG _                             ' GIOCondition     condition
 , BYVAL DWORD _                            ' GIOFunc          func
 , BYVAL DWORD _                            ' gpointer         user_data
 , BYVAL DWORD _                            ' GDestroyNotify   notify
 ) AS DWORD                                 ' guint

' ========================================================================================
'GSource * g_io_create_watch     (GIOChannel      *channel,
'                                 GIOCondition     condition);
' ========================================================================================
DECLARE FUNCTION g_io_create_watch CDECL LIB $GLIB_DLLNAME ALIAS "g_io_create_watch" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL LONG _                             ' GIOCondition     condition
 ) AS DWORD                                 ' GSource*

' ========================================================================================
'guint     g_io_add_watch        (GIOChannel      *channel,
'                                 GIOCondition     condition,
'                                 GIOFunc          func,
'                                 gpointer         user_data);
' ========================================================================================
DECLARE FUNCTION g_io_add_watch CDECL LIB $GLIB_DLLNAME ALIAS "g_io_add_watch" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL LONG _                             ' GIOCondition     condition
 , BYVAL DWORD _                            ' GIOFunc          func
 , BYVAL DWORD _                            ' gpointer         user_data
 ) AS DWORD                                 ' guint

'/* character encoding conversion involved functions.
' */

' ========================================================================================
'void                  g_io_channel_set_buffer_size      (GIOChannel   *channel,
'                                                         gsize         size);
' ========================================================================================
DECLARE SUB g_io_channel_set_buffer_size CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_buffer_size" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL DWORD _                            ' gsize            siz
 )                                          ' void

' ========================================================================================
'gsize                 g_io_channel_get_buffer_size      (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_buffer_size CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_buffer_size" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS DWORD                                 ' gsize

' ========================================================================================
'GIOCondition          g_io_channel_get_buffer_condition (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_buffer_condition CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_buffer_condition" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS LONG                                  ' GIOCondition

' ========================================================================================
'GIOStatus             g_io_channel_set_flags            (GIOChannel   *channel,
'                                                         GIOFlags      flags,
'                                                         GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_set_flags CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_flags" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL DWORD _                            ' GIOFlags      flags
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOFlags              g_io_channel_get_flags            (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_flags CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_flags" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS DWORD                                 ' GIOFlags

' ========================================================================================
'void                  g_io_channel_set_line_term        (GIOChannel   *channel,
'                                                         const gchar  *line_term,
'                                                         gint          length);
' ========================================================================================
DECLARE SUB g_io_channel_set_line_term CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_line_term" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYREF ASCIIZ _                           ' const gchar  *line_term
 , BYVAL LONG _                             ' gint          length
 )                                          ' void

' ========================================================================================
'G_CONST_RETURN gchar* g_io_channel_get_line_term        (GIOChannel   *channel,
'                                                         gint         *length);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_line_term CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_line_term" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'void            g_io_channel_set_buffered      (GIOChannel   *channel,
'                                                gboolean      buffered);
' ========================================================================================
DECLARE SUB g_io_channel_set_buffered CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_buffered" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYVAL LONG _                             ' gboolean      buffered
 )                                          ' void

' ========================================================================================
'gboolean         g_io_channel_get_buffered      (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_buffered CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_buffered" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS LONG                                  ' gboolean

' ========================================================================================
'GIOStatus             g_io_channel_set_encoding         (GIOChannel   *channel,
'                                                         const gchar  *encoding,
'                                                         GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_set_encoding CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_encoding" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 , BYREF ASCIIZ _                           ' const gchar  *encoding
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'G_CONST_RETURN gchar* g_io_channel_get_encoding         (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_encoding CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_encoding" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'void                  g_io_channel_set_close_on_unref   (GIOChannel   *channel,
'                                                         gboolean      do_close);
' ========================================================================================
DECLARE SUB g_io_channel_set_close_on_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_set_close_on_unref" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYVAL LONG _                             ' gboolean      do_close
 )                                          ' void

' ========================================================================================
'gboolean              g_io_channel_get_close_on_unref   (GIOChannel   *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_get_close_on_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_get_close_on_unref" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel      *channel
 ) AS LONG                                  ' gboolean

' ========================================================================================
'GIOStatus   g_io_channel_flush            (GIOChannel   *channel,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_flush CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_flush" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_read_line        (GIOChannel   *channel,
'                                           gchar       **str_return,
'                                           gsize        *length,
'                                           gsize        *terminator_pos,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_read_line CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read_line" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF DWORD _                            ' gchar       **str_return
 , BYREF DWORD _                            ' gsize        *length
 , BYREF DWORD _                            ' gsize        *terminator_pos
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_read_line_string (GIOChannel   *channel,
'                                           GString      *buffer,
'                                           gsize        *terminator_pos,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_read_line_string CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read_line_string" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYVAL GString PTR _                      ' GString      *buffer
 , BYREF DWORD _                            ' gsize        *terminator_pos
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_read_to_end      (GIOChannel   *channel,
'                                           gchar       **str_return,
'                                           gsize        *length,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_read_to_end CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read_to_end" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF DWORD _                            ' gchar       **str_return
 , BYREF DWORD _                            ' gsize        *length
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_read_chars       (GIOChannel   *channel,
'                                           gchar        *buf,
'                                           gsize         count,
'                                           gsize        *bytes_read,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_read_chars CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read_chars" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF ASCIIZ _                           ' gchar        *buf
 , BYVAL DWORD _                            ' gsize         count
 , BYREF DWORD _                            ' gsize        *bytes_read
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_read_unichar     (GIOChannel   *channel,
'                                           gunichar     *thechar,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_read_unichar CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_read_unichar" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF DWORD _                            ' gunichar     *thechar
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_write_chars      (GIOChannel   *channel,
'                                           const gchar  *buf,
'                                           gssize        count,
'                                           gsize        *bytes_written,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_write_chars CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_write_chars" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF ASCIIZ _                           ' const gchar  *buf
 , BYVAL LONG _                             ' gssize        count
 , BYREF DWORD _                            ' gsize        *bytes_written
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_write_unichar    (GIOChannel   *channel,
'                                           gunichar      thechar,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_write_unichar CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_write_unichar" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF DWORD _                            ' gunichar      thechar
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

' ========================================================================================
'GIOStatus   g_io_channel_seek_position    (GIOChannel   *channel,
'                                           gint64        offset,
'                                           GSeekType     type,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_seek_position CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_seek_position" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYREF QUAD _                             ' gint64        offset
 , BYVAL LONG _                             ' GSeekType     type
 , BYREF DWORD _                            ' GError      **error
 ) AS LONG                                  ' GIOStatus

'#ifdef G_OS_WIN32
'#define g_io_channel_new_file g_io_channel_new_file_utf8
'#endif

' ========================================================================================
'GIOChannel* g_io_channel_new_file         (const gchar  *filename,
'                                           const gchar  *mode,
'                                           GError      **error);
' ========================================================================================
DECLARE FUNCTION g_io_channel_new_file CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_new_file" ( _
   BYREF ASCIIZ _                           ' const gchar  *filename
 , BYREF ASCIIZ _                           ' const gchar  *mode
 , BYREF DWORD _                            ' GError      **error
 ) AS DWORD                                 ' GIOChannel*

'/* Error handling */

' ========================================================================================
'GQuark          g_io_channel_error_quark      (void);
' ========================================================================================
DECLARE FUNCTION g_io_channel_error_quark CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_error_quark" ( _
 ) AS DWORD                                 ' GQuark

DECLARE FUNCTION G_IO_CHANNEL_ERROR CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_error_quark" ( _
 ) AS DWORD                                 ' GQuark

' ========================================================================================
'GIOChannelError g_io_channel_error_from_errno (gint en);
' ========================================================================================
DECLARE FUNCTION g_io_channel_error_from_errno CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_error_from_errno" ( _
   BYVAL LONG _                             ' gint en
 ) AS LONG                                  ' GIOChannelError

'/* On Unix, IO channels created with this function for any file
' * descriptor or socket.
' *
' * On Win32, this can be used either for files opened with the MSVCRT
' * (the Microsoft run-time C library) _open() or _pipe, including file
' * descriptors 0, 1 and 2 (corresponding to stdin, stdout and stderr),
' * or for Winsock SOCKETs. If the parameter is a legal file
' * descriptor, it is assumed to be such, otherwise it should be a
' * SOCKET. This relies on SOCKETs and file descriptors not
' * overlapping. If you want to be certain, call either
' * g_io_channel_win32_new_fd() or g_io_channel_win32_new_socket()
' * instead as appropriate.
' *
' * The term file descriptor as used in the context of Win32 refers to
' * the emulated Unix-like file descriptors MSVCRT provides. The native
' * corresponding concept is file HANDLE. There isn't as of yet a way to
' * get GIOChannels for Win32 file HANDLEs.
' */

' ========================================================================================
'GIOChannel* g_io_channel_unix_new    (int         fd);
' ========================================================================================
DECLARE FUNCTION g_io_channel_unix_new CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_unix_new" ( _
   BYVAL LONG _                             ' int         fd
 ) AS DWORD                                 ' GIOChannel*

' ========================================================================================
'gint        g_io_channel_unix_get_fd (GIOChannel *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_unix_get_fd CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_unix_get_fd" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 ) AS LONG                                  ' gint


'/* Hook for GClosure / GSource integration. Don't touch */

'GLIB_VAR GSourceFuncs g_io_watch_funcs;

'#ifdef G_OS_WIN32

'/* You can use this "pseudo file descriptor" in a GPollFD to add
' * polling for Windows messages. GTK applications should not do that.
' */

'#define G_WIN32_MSG_HANDLE 19981206
%G_WIN32_MSG_HANDLE = 19981206

'/* Use this to get a GPollFD from a GIOChannel, so that you can call
' * g_io_channel_win32_poll(). After calling this you should only use
' * g_io_channel_read() to read from the GIOChannel, i.e. never read()
' * from the underlying file descriptor. For SOCKETs, it is possible to call
' * recv().
' */

' ========================================================================================
'void        g_io_channel_win32_make_pollfd (GIOChannel   *channel,
'                                            GIOCondition  condition,
'                                            GPollFD      *fd);
' ========================================================================================
DECLARE SUB g_io_channel_win32_make_pollfd CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_make_pollfd" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel   *channel
 , BYVAL DWORD _                            ' GIOCondition  condition
 , BYREF DWORD _                            ' GPollFD      *fd
 )                                          ' void

'/* This can be used to wait a until at least one of the channels is readable.
' * On Unix you would do a select() on the file descriptors of the channels.
' */

' ========================================================================================
'gint        g_io_channel_win32_poll   (GPollFD    *fds,
'                                       gint        n_fds,
'                                       gint        timeout_);
' ========================================================================================
DECLARE FUNCTION g_io_channel_win32_poll CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_poll" ( _
   BYVAL DWORD _                            ' GPollFD    *fds
 , BYVAL LONG _                             ' gint        n_fds
 , BYVAL LONG _                             ' gint        timeout_
 ) AS LONG                                  ' gint

'/* Create an IO channel for Windows messages for window handle hwnd. */
'#if GLIB_SIZEOF_VOID_P == 8
'/* We use gsize here so that it is still an integer type and not a
' * pointer, like the guint in the traditional prototype. We can't use
' * intptr_t as that is not portable enough.
' */
' ========================================================================================
'GIOChannel *g_io_channel_win32_new_messages (gsize hwnd);
'#else
'GIOChannel *g_io_channel_win32_new_messages (guint hwnd);
'#endif
' ========================================================================================
DECLARE FUNCTION g_io_channel_win32_new_messages CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_new_messages" ( _
   BYVAL DWORD _                            ' guint hwnd
 ) AS DWORD                                 ' GIOChannel*

'/* Create an IO channel for C runtime (emulated Unix-like) file
' * descriptors. After calling g_io_add_watch() on a IO channel
' * returned by this function, you shouldn't call read() on the file
' * descriptor. This is because adding polling for a file descriptor is
' * implemented on Win32 by starting a thread that sits blocked in a
' * read() from the file descriptor most of the time. All reads from
' * the file descriptor should be done by this internal GLib
' * thread. Your code should call only g_io_channel_read_chars().
' */
' ========================================================================================
'GIOChannel* g_io_channel_win32_new_fd (gint         fd);
' ========================================================================================
DECLARE FUNCTION g_io_channel_win32_new_fd CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_new_fd" ( _
   BYVAL LONG _                             ' gint         fd
 ) AS DWORD                                 ' GIOChannel*

'/* Get the C runtime file descriptor of a channel. */
' ========================================================================================
'gint        g_io_channel_win32_get_fd (GIOChannel *channel);
' ========================================================================================
DECLARE FUNCTION g_io_channel_win32_get_fd CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_get_fd" ( _
   BYVAL GIOChannel PTR _                   ' GIOChannel *channel
 ) AS LONG                                  ' gint

'/* Create an IO channel for a winsock socket. The parameter should be
' * a SOCKET. Contrary to IO channels for file descriptors (on *Win32),
' * you can use normal recv() or recvfrom() on sockets even if GLib
' * is polling them.
' */
' ========================================================================================
'GIOChannel *g_io_channel_win32_new_socket (gint socket);
' ========================================================================================
DECLARE FUNCTION g_io_channel_win32_new_socket CDECL LIB $GLIB_DLLNAME ALIAS "g_io_channel_win32_new_socket" ( _
   BYVAL LONG _                             ' gint socket
 ) AS DWORD                                 ' GIOChannel*

'#endif

'G_END_DECLS

'#endif /* __G_IOCHANNEL_H__ */
#ENDIF   ' /* __GIOCHANNEL_INC__ */
