'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_LIST_H__
'#define __G_LIST_H__

#IF NOT %DEF(%GLIST_INC)
    %GLIST_INC = 1

#INCLUDE ONCE "gmem.inc"

'G_BEGIN_DECLS

'typedef struct _GList GList;

'struct _GList
'{
'  gpointer data;
'  GList *next;
'  GList *prev;
'};

TYPE GList
   data AS LONG        ' must be a LONG to allow for negative numbers in numeric lists
   next AS GList PTR
   prev AS GList PTR
END TYPE

'/* Doubly linked lists
' */

' ========================================================================================
'GList*   g_list_alloc                   (void) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_alloc CDECL LIB $GLIB_DLLNAME ALIAS "g_list_alloc" ( _
 ) AS DWORD                                 ' GList*

' ========================================================================================
'void     g_list_free                    (GList            *list);
' ========================================================================================
DECLARE SUB g_list_free CDECL LIB $GLIB_DLLNAME ALIAS "g_list_free" ( _
   BYVAL GList PTR _                        ' GList            *list
 )                                          ' void

' ========================================================================================
'void     g_list_free_1                  (GList            *list);
' ========================================================================================
DECLARE SUB g_list_free_1 CDECL LIB $GLIB_DLLNAME ALIAS "g_list_free_1" ( _
   BYVAL GList PTR _                        ' GList            *list
 )                                          ' void

' ========================================================================================
'#define  g_list_free1                   g_list_free_1
' ========================================================================================
DECLARE SUB g_list_free1 CDECL LIB $GLIB_DLLNAME ALIAS "g_list_free_1" ( _
   BYVAL GList PTR _                        ' GList            *list
 )                                          ' void
' ========================================================================================

' ========================================================================================
'GList*   g_list_append                  (GList            *list,
'                                         gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_append CDECL LIB $GLIB_DLLNAME ALIAS "g_list_append" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gpointer          data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_prepend                 (GList            *list,
'                                         gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_prepend CDECL LIB $GLIB_DLLNAME ALIAS "g_list_prepend" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gpointer          data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_insert                  (GList            *list,
'                                         gpointer          data,
'                                         gint              position) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_insert CDECL LIB $GLIB_DLLNAME ALIAS "g_list_insert" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gpointer          data
 , BYVAL LONG _                             ' gint              position
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_insert_sorted           (GList            *list,
'                                         gpointer          data,
'                                         GCompareFunc      func) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_insert_sorted CDECL LIB $GLIB_DLLNAME ALIAS "g_list_insert_sorted" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gpointer          data
 , BYVAL DWORD _                            ' GCompareFunc      func
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_insert_sorted_with_data (GList            *list,
'                                         gpointer          data,
'                                         GCompareDataFunc  func,
'                                         gpointer          user_data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_insert_sorted_with_data CDECL LIB $GLIB_DLLNAME ALIAS "g_list_insert_sorted_with_data" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gpointer          data
 , BYVAL LONG _                             ' GCompareFunc      func
 , BYVAL DWORD _                            ' gpointer          user_data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_insert_before           (GList            *list,
'                                         GList            *sibling,
'                                         gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_insert_before CDECL LIB $GLIB_DLLNAME ALIAS "g_list_insert_before" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL GList PTR _                        ' GList            *sibling
 , BYVAL DWORD _                            ' gpointer          data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_concat                  (GList            *list1,
'                                         GList            *list2) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_concat CDECL LIB $GLIB_DLLNAME ALIAS "g_list_concat" ( _
   BYVAL GList PTR _                        ' GList            *list1
 , BYVAL GList PTR _                        ' GList            *list2
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_remove                  (GList            *list,
'                                         gconstpointer     data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_remove CDECL LIB $GLIB_DLLNAME ALIAS "g_list_remove" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gconstpointer     data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_remove_all              (GList            *list,
'                                         gconstpointer     data) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_remove_all CDECL LIB $GLIB_DLLNAME ALIAS "g_list_remove_all" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gconstpointer     data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_remove_link             (GList            *list,
'                                         GList            *llink) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_remove_link CDECL LIB $GLIB_DLLNAME ALIAS "g_list_remove_link" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL GList PTR _                        ' GList            *llink
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_delete_link             (GList            *list,
'                                         GList            *link_) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_delete_link CDECL LIB $GLIB_DLLNAME ALIAS "g_list_delete_link" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL GList PTR _                        ' GList            *link_
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_reverse                 (GList            *list) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_reverse CDECL LIB $GLIB_DLLNAME ALIAS "g_list_reverse" ( _
   BYVAL GList PTR _                        ' GList            *list
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_copy                    (GList            *list) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_copy CDECL LIB $GLIB_DLLNAME ALIAS "g_list_copy" ( _
   BYVAL GList PTR _                        ' GList            *list
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_nth                     (GList            *list,
'                                         guint             n);
' ========================================================================================
DECLARE FUNCTION g_list_nth CDECL LIB $GLIB_DLLNAME ALIAS "g_list_nth" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' guint             n
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_nth_prev                (GList            *list,
'                                         guint             n);
' ========================================================================================
DECLARE FUNCTION g_list_nth_prev CDECL LIB $GLIB_DLLNAME ALIAS "g_list_nth_prev" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' guint             n
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_find                    (GList            *list,
'                                         gconstpointer     data);
' ========================================================================================
DECLARE FUNCTION g_list_find CDECL LIB $GLIB_DLLNAME ALIAS "g_list_find" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gconstpointer     data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_find_custom             (GList            *list,
'                                         gconstpointer     data,
'                                         GCompareFunc      func);
' ========================================================================================
DECLARE FUNCTION g_list_find_custom CDECL LIB $GLIB_DLLNAME ALIAS "g_list_find_custom" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gconstpointer     data
 , BYVAL DWORD _                            ' GCompareFunc      func
 ) AS DWORD                                 ' GList*

' ========================================================================================
'gint     g_list_position                (GList            *list,
'                                         GList            *llink);
' ========================================================================================
DECLARE FUNCTION g_list_position CDECL LIB $GLIB_DLLNAME ALIAS "g_list_position" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL GList PTR _                        ' GList            *llink
 ) AS LONG                                  ' gint

' ========================================================================================
'gint     g_list_index                   (GList            *list,
'                                         gconstpointer     data);
' ========================================================================================
DECLARE FUNCTION g_list_index CDECL LIB $GLIB_DLLNAME ALIAS "g_list_index" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' gconstpointer     data
 ) AS LONG                                  ' gint

' ========================================================================================
'GList*   g_list_last                    (GList            *list);
' ========================================================================================
DECLARE FUNCTION g_list_last CDECL LIB $GLIB_DLLNAME ALIAS "g_list_last" ( _
   BYVAL GList PTR _                        ' GList            *list
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_first                   (GList            *list);
' ========================================================================================
DECLARE FUNCTION g_list_first CDECL LIB $GLIB_DLLNAME ALIAS "g_list_first" ( _
   BYVAL GList PTR _                        ' GList            *list
 ) AS DWORD                                 ' GList*

' ========================================================================================
'guint    g_list_length                  (GList            *list);
' ========================================================================================
DECLARE FUNCTION g_list_length CDECL LIB $GLIB_DLLNAME ALIAS "g_list_length" ( _
   BYVAL GList PTR _                        ' GList            *list
 ) AS DWORD                                 ' guint

' ========================================================================================
'void     g_list_foreach                 (GList            *list,
'                                         GFunc             func,
'                                         gpointer          user_data);
' ========================================================================================
DECLARE SUB g_list_foreach CDECL LIB $GLIB_DLLNAME ALIAS "g_list_foreach" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' GFunc             func
 , BYVAL DWORD _                            ' gpointer          user_data
 )                                          ' void

' ========================================================================================
'GList*   g_list_sort                    (GList            *list,
'                                         GCompareFunc      compare_func) G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_sort CDECL LIB $GLIB_DLLNAME ALIAS "g_list_sort" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 ) AS DWORD                                 ' GList*

' ========================================================================================
'GList*   g_list_sort_with_data          (GList            *list,
'                                         GCompareDataFunc  compare_func,
'                                         gpointer          user_data)  G_GNUC_WARN_UNUSED_RESULT;
' ========================================================================================
DECLARE FUNCTION g_list_sort_with_data CDECL LIB $GLIB_DLLNAME ALIAS "g_list_sort_with_data" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' GCompareFunc      compare_func
 , BYVAL DWORD _                            ' gpointer          user_data
 ) AS DWORD                                 ' GList*

' ========================================================================================
'gpointer g_list_nth_data                (GList            *list,
'                                         guint             n);
' ========================================================================================
DECLARE FUNCTION g_list_nth_data CDECL LIB $GLIB_DLLNAME ALIAS "g_list_nth_data" ( _
   BYVAL GList PTR _                        ' GList            *list
 , BYVAL DWORD _                            ' guint             n
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'#define g_list_previous(list)           ((list) ? (((GList *)(list))->prev) : NULL)
' ========================================================================================
MACRO g_list_previous(list) = IIF&(list, @list.prev, %NULL)

' ========================================================================================
'#define g_list_next(list)           ((list) ? (((GList *)(list))->next) : NULL)
' ========================================================================================
MACRO g_list_next(list) = IIF&(list, @list.next, %NULL)

'#ifndef G_DISABLE_DEPRECATED
'void     g_list_push_allocator          (gpointer          allocator);
'void     g_list_pop_allocator           (void);
'#endif

'G_END_DECLS

'#endif /* __G_LIST_H__ */
#ENDIF   ' /* __GLIST_INC__ */
