'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_RAND_H__
'#define __G_RAND_H__

#IF NOT %DEF(%GRAND_INC)
    %GRAND_INC = 1

#INCLUDE ONCE "gtypes.inc"

'G_BEGIN_DECLS

'typedef struct _GRand           GRand;

'/* GRand - a good and fast random number generator: Mersenne Twister
' * see http://www.math.keio.ac.jp/~matumoto/emt.html for more info.
' * The range functions return a value in the intervall [begin, end).
' * int          -> [0..2^32-1]
' * int_range    -> [begin..end-1]
' * double       -> [0..1)
' * double_range -> [begin..end)
' */

' ========================================================================================
'GRand*  g_rand_new_with_seed  (guint32  seed);
' ========================================================================================
DECLARE FUNCTION g_rand_new_with_seed CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_new_with_seed" ( _
   BYVAL DWORD _                            ' guint32  seed
 ) AS DWORD                                 ' GRand*

' ========================================================================================
'GRand*  g_rand_new_with_seed_array (const guint32 *seed,
'                                    guint seed_length);
' ========================================================================================
DECLARE FUNCTION g_rand_new_with_seed_array CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_new_with_seed_array" ( _
   BYREF DWORD _                            ' const guint32 seed
 , BYVAL DWORD _                            ' guint         seed_length
 ) AS DWORD                                 ' GRand*

' ========================================================================================
'GRand*  g_rand_new            (void);
' ========================================================================================
DECLARE FUNCTION g_rand_new CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_new" ( _
 ) AS DWORD                                 ' GRand*

' ========================================================================================
'void    g_rand_free           (GRand   *rand_);
' ========================================================================================
DECLARE SUB g_rand_free CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_free" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 )                                          ' void

' ========================================================================================
'GRand*  g_rand_copy           (GRand   *rand_);
' ========================================================================================
DECLARE FUNCTION g_rand_copy CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_copy" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 ) AS DWORD                                 ' GRand*

' ========================================================================================
'void    g_rand_set_seed       (GRand   *rand_,
'                               guint32  seed);
' ========================================================================================
DECLARE SUB g_rand_set_seed CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_set_seed" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 , BYVAL DWORD _                            ' guint32  seed
 )                                          ' void

' ========================================================================================
'void   g_rand_set_seed_array (GRand         *rand_,
'                              const guint32 *seed,
'                              guint          seed_length);
' ========================================================================================
DECLARE SUB g_rand_set_seed_array CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_set_seed_array" ( _
   BYVAL DWORD _                            ' GRand         *rand_
 , BYREF DWORD _                            ' const guint32  seed
 , BYVAL DWORD _                            ' guint          seed_length
 )                                          ' void

' ========================================================================================
'#define g_rand_boolean(rand_) ((g_rand_int (rand_) & (1 << 15)) != 0)
' ========================================================================================
MACRO g_rand_boolean(rand_) = ((g_rand_int (rand_) AND &H8000??) <> 0)


' ========================================================================================
'guint32 g_rand_int            (GRand   *rand_);
' ========================================================================================
DECLARE FUNCTION g_rand_int CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_int" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 ) AS DWORD                                 ' guint32

' ========================================================================================
'gint32  g_rand_int_range      (GRand   *rand_,
'                               gint32   begin,
'                               gint32   end);
' ========================================================================================
DECLARE FUNCTION g_rand_int_range CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_int_range" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 , BYVAL LONG _                             ' gint32   begin
 , BYVAL LONG _                             ' gint32   end
 ) AS LONG                                  ' gint32

' ========================================================================================
'gdouble g_rand_double         (GRand   *rand_);
' ========================================================================================
DECLARE FUNCTION g_rand_double CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_double" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 ) AS DOUBLE                                ' gdouble

' ========================================================================================
'gdouble g_rand_double_range   (GRand   *rand_,
'                               gdouble  begin,
'                               gdouble  end);
' ========================================================================================
DECLARE FUNCTION g_rand_double_range CDECL LIB $GLIB_DLLNAME ALIAS "g_rand_double_range" ( _
   BYVAL DWORD _                            ' GRand   *rand_
 , BYVAL DOUBLE _                           ' gdouble  begin
 , BYVAL DOUBLE _                           ' gdouble  end
 ) AS DOUBLE                                ' gdouble

' ========================================================================================
'void    g_random_set_seed     (guint32  seed);
' ========================================================================================
DECLARE SUB g_random_set_seed CDECL LIB $GLIB_DLLNAME ALIAS "g_random_set_seed" ( _
   BYVAL DWORD _                            ' guint32  seed
 )                                          ' void

' ========================================================================================
'#define g_random_boolean() ((g_random_int () & (1 << 15)) != 0)
' ========================================================================================
MACRO g_random_boolean() = ((g_random_int () AND &H8000??) <> 0)

' ========================================================================================
'guint32 g_random_int          (void);
' ========================================================================================
DECLARE FUNCTION g_random_int CDECL LIB $GLIB_DLLNAME ALIAS "g_random_int" ( _
 ) AS DWORD                                 ' guint32

' ========================================================================================
'gint32  g_random_int_range    (gint32   begin,
'                               gint32   end);
' ========================================================================================
DECLARE FUNCTION g_random_int_range CDECL LIB $GLIB_DLLNAME ALIAS "g_random_int_range" ( _
   BYVAL LONG _                             ' gint32   begin
 , BYVAL LONG _                             ' gint32   end
 ) AS LONG                                  ' gint32

' ========================================================================================
'gdouble g_random_double       (void);
' ========================================================================================
DECLARE FUNCTION g_random_double CDECL LIB $GLIB_DLLNAME ALIAS "g_random_double" ( _
 ) AS DOUBLE                                ' gdouble

' ========================================================================================
'gdouble g_random_double_range (gdouble  begin,
'                               gdouble  end);
' ========================================================================================
DECLARE FUNCTION g_random_double_range CDECL LIB $GLIB_DLLNAME ALIAS "g_random_double_range" ( _
   BYVAL DOUBLE _                           ' gdouble  begin
 , BYVAL DOUBLE _                           ' gdouble  end
 ) AS DOUBLE                                ' gdouble

'G_END_DECLS

'#endif /* __G_RAND_H__ */
#ENDIF   ' /* __GRAND_INC__ */
