'/* GRegex -- regular expression API wrapper around PCRE.
' *
' * Copyright (C) 1999, 2000 Scott Wimer
' * Copyright (C) 2004, Matthias Clasen <mclasen@redhat.com>
' * Copyright (C) 2005 - 2007, Marco Barisione <marco@barisione.org>
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2.1 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the Free Software
' * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_REGEX_H__
'#define __G_REGEX_H__

#IF NOT %DEF(%GREGEX_INC)
    %GREGEX_INC = 1

#INCLUDE ONCE "gerror.inc"
#INCLUDE ONCE "gstring.inc"

'G_BEGIN_DECLS

'typedef enum
'{
'  G_REGEX_ERROR_COMPILE,
'  G_REGEX_ERROR_OPTIMIZE,
'  G_REGEX_ERROR_REPLACE,
'  G_REGEX_ERROR_MATCH,
'  G_REGEX_ERROR_INTERNAL,

'  /* These are the error codes from PCRE + 100 */
'  G_REGEX_ERROR_STRAY_BACKSLASH = 101,
'  G_REGEX_ERROR_MISSING_CONTROL_CHAR = 102,
'  G_REGEX_ERROR_UNRECOGNIZED_ESCAPE = 103,
'  G_REGEX_ERROR_QUANTIFIERS_OUT_OF_ORDER = 104,
'  G_REGEX_ERROR_QUANTIFIER_TOO_BIG = 105,
'  G_REGEX_ERROR_UNTERMINATED_CHARACTER_CLASS = 106,
'  G_REGEX_ERROR_INVALID_ESCAPE_IN_CHARACTER_CLASS = 107,
'  G_REGEX_ERROR_RANGE_OUT_OF_ORDER = 108,
'  G_REGEX_ERROR_NOTHING_TO_REPEAT = 109,
'  G_REGEX_ERROR_UNRECOGNIZED_CHARACTER = 112,
'  G_REGEX_ERROR_POSIX_NAMED_CLASS_OUTSIDE_CLASS = 113,
'  G_REGEX_ERROR_UNMATCHED_PARENTHESIS = 114,
'  G_REGEX_ERROR_INEXISTENT_SUBPATTERN_REFERENCE = 115,
'  G_REGEX_ERROR_UNTERMINATED_COMMENT = 118,
'  G_REGEX_ERROR_EXPRESSION_TOO_LARGE = 120,
'  G_REGEX_ERROR_MEMORY_ERROR = 121,
'  G_REGEX_ERROR_VARIABLE_LENGTH_LOOKBEHIND = 125,
'  G_REGEX_ERROR_MALFORMED_CONDITION = 126,
'  G_REGEX_ERROR_TOO_MANY_CONDITIONAL_BRANCHES = 127,
'  G_REGEX_ERROR_ASSERTION_EXPECTED = 128,
'  G_REGEX_ERROR_UNKNOWN_POSIX_CLASS_NAME = 130,
'  G_REGEX_ERROR_POSIX_COLLATING_ELEMENTS_NOT_SUPPORTED = 131,
'  G_REGEX_ERROR_HEX_CODE_TOO_LARGE = 134,
'  G_REGEX_ERROR_INVALID_CONDITION = 135,
'  G_REGEX_ERROR_SINGLE_BYTE_MATCH_IN_LOOKBEHIND = 136,
'  G_REGEX_ERROR_INFINITE_LOOP = 140,
'  G_REGEX_ERROR_MISSING_SUBPATTERN_NAME_TERMINATOR = 142,
'  G_REGEX_ERROR_DUPLICATE_SUBPATTERN_NAME = 143,
'  G_REGEX_ERROR_MALFORMED_PROPERTY = 146,
'  G_REGEX_ERROR_UNKNOWN_PROPERTY = 147,
'  G_REGEX_ERROR_SUBPATTERN_NAME_TOO_LONG = 148,
'  G_REGEX_ERROR_TOO_MANY_SUBPATTERNS = 149,
'  G_REGEX_ERROR_INVALID_OCTAL_VALUE = 151,
'  G_REGEX_ERROR_TOO_MANY_BRANCHES_IN_DEFINE = 154,
'  G_REGEX_ERROR_DEFINE_REPETION = 155,
'  G_REGEX_ERROR_INCONSISTENT_NEWLINE_OPTIONS = 156,
'  G_REGEX_ERROR_MISSING_BACK_REFERENCE = 157
'} GRegexError;

%G_REGEX_ERROR_COMPILE                                = 0
%G_REGEX_ERROR_OPTIMIZE                               = 1
%G_REGEX_ERROR_REPLACE                                = 2
%G_REGEX_ERROR_MATCH                                  = 3
%G_REGEX_ERROR_INTERNAL                               = 4

'/* These are the error codes from PCRE + 100 */
%G_REGEX_ERROR_STRAY_BACKSLASH                        = 101
%G_REGEX_ERROR_MISSING_CONTROL_CHAR                   = 102
%G_REGEX_ERROR_UNRECOGNIZED_ESCAPE                    = 103
%G_REGEX_ERROR_QUANTIFIERS_OUT_OF_ORDER               = 104
%G_REGEX_ERROR_QUANTIFIER_TOO_BIG                     = 105
%G_REGEX_ERROR_UNTERMINATED_CHARACTER_CLASS           = 106
%G_REGEX_ERROR_INVALID_ESCAPE_IN_CHARACTER_CLASS      = 107
%G_REGEX_ERROR_RANGE_OUT_OF_ORDER                     = 108
%G_REGEX_ERROR_NOTHING_TO_REPEAT                      = 109
%G_REGEX_ERROR_UNRECOGNIZED_CHARACTER                 = 112
%G_REGEX_ERROR_POSIX_NAMED_CLASS_OUTSIDE_CLASS        = 113
%G_REGEX_ERROR_UNMATCHED_PARENTHESIS                  = 114
%G_REGEX_ERROR_INEXISTENT_SUBPATTERN_REFERENCE        = 115
%G_REGEX_ERROR_UNTERMINATED_COMMENT                   = 118
%G_REGEX_ERROR_EXPRESSION_TOO_LARGE                   = 120
%G_REGEX_ERROR_MEMORY_ERROR                           = 121
%G_REGEX_ERROR_VARIABLE_LENGTH_LOOKBEHIND             = 125
%G_REGEX_ERROR_MALFORMED_CONDITION                    = 126
%G_REGEX_ERROR_TOO_MANY_CONDITIONAL_BRANCHES          = 127
%G_REGEX_ERROR_ASSERTION_EXPECTED                     = 128
%G_REGEX_ERROR_UNKNOWN_POSIX_CLASS_NAME               = 130
%G_REGEX_ERROR_POSIX_COLLATING_ELEMENTS_NOT_SUPPORTED = 131
%G_REGEX_ERROR_HEX_CODE_TOO_LARGE                     = 134
%G_REGEX_ERROR_INVALID_CONDITION                      = 135
%G_REGEX_ERROR_SINGLE_BYTE_MATCH_IN_LOOKBEHIND        = 136
%G_REGEX_ERROR_INFINITE_LOOP                          = 140
%G_REGEX_ERROR_MISSING_SUBPATTERN_NAME_TERMINATOR     = 142
%G_REGEX_ERROR_DUPLICATE_SUBPATTERN_NAME              = 143
%G_REGEX_ERROR_MALFORMED_PROPERTY                     = 146
%G_REGEX_ERROR_UNKNOWN_PROPERTY                       = 147
%G_REGEX_ERROR_SUBPATTERN_NAME_TOO_LONG               = 148
%G_REGEX_ERROR_TOO_MANY_SUBPATTERNS                   = 149
%G_REGEX_ERROR_INVALID_OCTAL_VALUE                    = 151
%G_REGEX_ERROR_TOO_MANY_BRANCHES_IN_DEFINE            = 154
%G_REGEX_ERROR_DEFINE_REPETION                        = 155
%G_REGEX_ERROR_INCONSISTENT_NEWLINE_OPTIONS           = 156
%G_REGEX_ERROR_MISSING_BACK_REFERENCE                 = 157

' ========================================================================================
'#define G_REGEX_ERROR g_regex_error_quark ()
'GQuark g_regex_error_quark (void);
' ========================================================================================
DECLARE FUNCTION g_regex_error_quark CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_error_quark" ( _
 ) AS DWORD                                 ' GQuark

DECLARE FUNCTION G_REGEX_ERROR CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_error_quark" ( _
 ) AS DWORD                                 ' GQuark

'/* Remember to update G_REGEX_COMPILE_MASK in gregex.c after
' * adding a new flag. */
'typedef enum
'{
'  G_REGEX_CASELESS          = 1 << 0,
'  G_REGEX_MULTILINE         = 1 << 1,
'  G_REGEX_DOTALL            = 1 << 2,
'  G_REGEX_EXTENDED          = 1 << 3,
'  G_REGEX_ANCHORED          = 1 << 4,
'  G_REGEX_DOLLAR_ENDONLY    = 1 << 5,
'  G_REGEX_UNGREEDY          = 1 << 9,
'  G_REGEX_RAW               = 1 << 11,
'  G_REGEX_NO_AUTO_CAPTURE   = 1 << 12,
'  G_REGEX_OPTIMIZE          = 1 << 13,
'  G_REGEX_DUPNAMES          = 1 << 19,
'  G_REGEX_NEWLINE_CR        = 1 << 20,
'  G_REGEX_NEWLINE_LF        = 1 << 21,
'  G_REGEX_NEWLINE_CRLF      = G_REGEX_NEWLINE_CR | G_REGEX_NEWLINE_LF
'} GRegexCompileFlags;

%G_REGEX_CASELESS          = &H1??
%G_REGEX_MULTILINE         = &H2??
%G_REGEX_DOTALL            = &H4??
%G_REGEX_EXTENDED          = &H8??
%G_REGEX_ANCHORED          = &H10??
%G_REGEX_DOLLAR_ENDONLY    = &H20??
%G_REGEX_UNGREEDY          = &H200??
%G_REGEX_RAW               = &H800??
%G_REGEX_NO_AUTO_CAPTURE   = &H1000??
%G_REGEX_OPTIMIZE          = &H2000??
%G_REGEX_DUPNAMES          = &H80000??
%G_REGEX_NEWLINE_CR        = &H100000??
%G_REGEX_NEWLINE_LF        = &H200000??
%G_REGEX_NEWLINE_CRLF      = %G_REGEX_NEWLINE_CR OR %G_REGEX_NEWLINE_LF

'/* Remember to update G_REGEX_MATCH_MASK in gregex.c after
' * adding a new flag. */
'typedef enum
'{
'  G_REGEX_MATCH_ANCHORED      = 1 << 4,
'  G_REGEX_MATCH_NOTBOL        = 1 << 7,
'  G_REGEX_MATCH_NOTEOL        = 1 << 8,
'  G_REGEX_MATCH_NOTEMPTY      = 1 << 10,
'  G_REGEX_MATCH_PARTIAL       = 1 << 15,
'  G_REGEX_MATCH_NEWLINE_CR    = 1 << 20,
'  G_REGEX_MATCH_NEWLINE_LF    = 1 << 21,
'  G_REGEX_MATCH_NEWLINE_CRLF  = G_REGEX_MATCH_NEWLINE_CR | G_REGEX_MATCH_NEWLINE_LF,
'  G_REGEX_MATCH_NEWLINE_ANY   = 1 << 22
'} GRegexMatchFlags;

%G_REGEX_MATCH_ANCHORED      = &H10??
%G_REGEX_MATCH_NOTBOL        = &H80??
%G_REGEX_MATCH_NOTEOL        = &H100??
%G_REGEX_MATCH_NOTEMPTY      = &H400??
%G_REGEX_MATCH_PARTIAL       = &H8000??
%G_REGEX_MATCH_NEWLINE_CR    = &H100000??
%G_REGEX_MATCH_NEWLINE_LF    = &H200000??
%G_REGEX_MATCH_NEWLINE_CRLF  = %G_REGEX_MATCH_NEWLINE_CR OR %G_REGEX_MATCH_NEWLINE_LF
%G_REGEX_MATCH_NEWLINE_ANY   = &H400000??

'typedef struct _GRegex      GRegex;
'typedef struct _GMatchInfo   GMatchInfo;

'typedef gboolean (*GRegexEvalCallback)      (const GMatchInfo *match_info,
'                   GString          *result,
'                   gpointer          user_data);

'FUNCTION GRegexEvalCallback (BYVAL match_info AS DWORD, BYVAL result AS GString PTR, BYVAL user_data AS DWORD) AS LONG

' ========================================================================================
'GRegex       *g_regex_new         (const gchar         *pattern,
'                                   GRegexCompileFlags   compile_options,
'                                   GRegexMatchFlags     match_options,
'                                   GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_new CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_new" ( _
   BYREF ASCIIZ _                           ' const gchar         *pattern
 , BYVAL DWORD _                            ' GRegexCompileFlags   compile_options
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' GRegex*

' ========================================================================================
'GRegex           *g_regex_ref         (GRegex              *regex);
' ========================================================================================
DECLARE FUNCTION g_regex_ref CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_ref" ( _
   BYVAL DWORD _                            ' GRegex              *regex
 ) AS DWORD                                 ' GRegex*

' ========================================================================================
'void        g_regex_unref         (GRegex              *regex);
' ========================================================================================
DECLARE SUB g_regex_unref CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_unref" ( _
   BYVAL DWORD _                            ' GRegex              *regex
 )                                          ' void

' ========================================================================================
'const gchar    *g_regex_get_pattern      (const GRegex        *regex);
' ========================================================================================
DECLARE FUNCTION g_regex_get_pattern CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_get_pattern" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gint        g_regex_get_max_backref   (const GRegex        *regex);
' ========================================================================================
DECLARE FUNCTION g_regex_get_max_backref CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_get_max_backref" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 ) AS LONG                                  ' gint

' ========================================================================================
'gint        g_regex_get_capture_count   (const GRegex        *regex);
' ========================================================================================
DECLARE FUNCTION g_regex_get_capture_count CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_get_capture_count" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 ) AS LONG                                  ' gint

' ========================================================================================
'gint        g_regex_get_string_number   (const GRegex        *regex,
'                                         const gchar         *name);
' ========================================================================================
DECLARE FUNCTION g_regex_get_string_number CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_get_string_number" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *name
 ) AS LONG                                  ' gint

' ========================================================================================
'gchar       *g_regex_escape_string      (const gchar         *string,
'                                         gint                 length);
' ========================================================================================
DECLARE FUNCTION g_regex_escape_string CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_escape_string" ( _
   BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gint                 length
 ) AS DWORD                                 ' gchar*

'/* Matching. */

' ========================================================================================
'gboolean     g_regex_match_simple      (const gchar         *pattern,
'                                        const gchar         *string,
'                                        GRegexCompileFlags   compile_options,
'                                        GRegexMatchFlags     match_options);
' ========================================================================================
DECLARE FUNCTION g_regex_match_simple CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_match_simple" ( _
   BYREF ASCIIZ _                           ' const gchar         *pattern
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL DWORD _                            ' GRegexCompileFlags   compile_options
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_regex_match         (const GRegex        *regex,
'                                    const gchar         *string,
'                                    GRegexMatchFlags     match_options,
'                                    GMatchInfo         **match_info);
' ========================================================================================
DECLARE FUNCTION g_regex_match CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_match" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GMatchInfo         **match_info
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_regex_match_full      (const GRegex        *regex,
'                                      const gchar         *string,
'                                      gssize               string_len,
'                                      gint                 start_position,
'                                      GRegexMatchFlags     match_options,
'                                      GMatchInfo         **match_info,
'                                      GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_match_full CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_match_full" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GMatchInfo         **match_info
 , BYREF DWORD _                            ' GError             **error
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_regex_match_all      (const GRegex        *regex,
'                                     const gchar         *string,
'                                     GRegexMatchFlags     match_options,
'                                     GMatchInfo         **match_info);
' ========================================================================================
DECLARE FUNCTION g_regex_match_all CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_match_all" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GMatchInfo         **match_info
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_regex_match_all_full   (const GRegex        *regex,
'                                       const gchar         *string,
'                                       gssize               string_len,
'                                       gint                 start_position,
'                                       GRegexMatchFlags     match_options,
'                                       GMatchInfo         **match_info,
'                                       GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_match_all_full CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_match_all_full" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GMatchInfo         **match_info
 , BYREF DWORD _                            ' GError             **error
 ) AS LONG                                  ' gboolean

'/* String splitting. */

' ========================================================================================
'gchar      **g_regex_split_simple      (const gchar         *pattern,
'                                        const gchar         *string,
'                                        GRegexCompileFlags   compile_options,
'                                        GRegexMatchFlags     match_options);
' ========================================================================================
DECLARE FUNCTION g_regex_split_simple CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_split_simple" ( _
   BYREF ASCIIZ _                           ' const gchar         *pattern
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL DWORD _                            ' GRegexCompileFlags   compile_options
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 ) AS DWORD                                 ' gchar**

' ========================================================================================
'gchar      **g_regex_split         (const GRegex        *regex,
'                                    const gchar         *string,
'                                    GRegexMatchFlags     match_options);
' ========================================================================================
DECLARE FUNCTION g_regex_split CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_split" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 ) AS DWORD                                 ' gchar**

' ========================================================================================
'gchar      **g_regex_split_full      (const GRegex        *regex,
'                                      const gchar         *string,
'                                      gssize               string_len,
'                                      gint                 start_position,
'                                      GRegexMatchFlags     match_options,
'                                      gint                 max_tokens,
'                                      GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_split_full CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_split_full" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYVAL LONG _                             ' gint                 max_tokens
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar**

'/* String replacement. */

' ========================================================================================
'gchar       *g_regex_replace      (const GRegex        *regex,
'                                   const gchar         *string,
'                                   gssize               string_len,
'                                   gint                 start_position,
'                                   const gchar         *replacement,
'                                   GRegexMatchFlags     match_options,
'                                   GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_replace CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_replace" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYREF ASCIIZ _                           ' const gchar         *replacement
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar       *g_regex_replace_literal   (const GRegex        *regex,
'                                        const gchar         *string,
'                                        gssize               string_len,
'                                        gint                 start_position,
'                                        const gchar         *replacement,
'                                        GRegexMatchFlags     match_options,
'                                        GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_replace_literal CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_replace_literal" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYREF ASCIIZ _                           ' const gchar         *replacement
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar       *g_regex_replace_eval      (const GRegex        *regex,
'                                        const gchar         *string,
'                                        gssize               string_len,
'                                        gint                 start_position,
'                                        GRegexMatchFlags     match_options,
'                                        GRegexEvalCallback   eval,
'                                        gpointer             user_data,
'                                        GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_replace_eval CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_replace_eval" ( _
   BYVAL DWORD _                            ' const GRegex        *regex
 , BYREF ASCIIZ _                           ' const gchar         *string
 , BYVAL LONG _                             ' gssize               string_len
 , BYVAL LONG _                             ' gint                 start_position
 , BYVAL DWORD _                            ' GRegexMatchFlags     match_options
 , BYVAL DWORD _                            ' GRegexEvalCallback   eval
 , BYVAL DWORD _                            ' gpointer             user_data
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gboolean     g_regex_check_replacement   (const gchar         *replacement,
'                                          gboolean            *has_references,
'                                          GError             **error);
' ========================================================================================
DECLARE FUNCTION g_regex_check_replacement CDECL LIB $GLIB_DLLNAME ALIAS "g_regex_check_replacement" ( _
   BYREF ASCIIZ _                           ' const gchar         *replacement
 , BYREF LONG _                             ' gboolean            *has_references
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar*

'/* Match info */

' ========================================================================================
'GRegex       *g_match_info_get_regex   (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_get_regex CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_get_regex" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS DWORD                                 ' GRegex*

' ========================================================================================
'const gchar      *g_match_info_get_string       (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_get_string CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_get_string" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'void        g_match_info_free      (GMatchInfo          *match_info);
' ========================================================================================
DECLARE SUB g_match_info_free CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_free" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 )                                          ' void

' ========================================================================================
'gboolean     g_match_info_next      (GMatchInfo          *match_info,
'                                     GError             **error);
' ========================================================================================
DECLARE FUNCTION g_match_info_next CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_next" ( _
   BYVAL DWORD _                            ' GMatchInfo          *match_info
 , BYREF DWORD _                            ' GError             **error
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean     g_match_info_matches      (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_matches CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_matches" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gint        g_match_info_get_match_count   (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_get_match_count CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_get_match_count" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS LONG                                  ' gint

' ========================================================================================
'gboolean     g_match_info_is_partial_match   (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_is_partial_match CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_is_partial_match" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gchar       *g_match_info_expand_references(const GMatchInfo    *match_info,
'                                            const gchar         *string_to_expand,
'                                            GError             **error);
' ========================================================================================
DECLARE FUNCTION g_match_info_expand_references CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_expand_references" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 , BYREF ASCIIZ _                           ' const gchar         *string_to_expand
 , BYREF DWORD _                            ' GError             **error
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar       *g_match_info_fetch      (const GMatchInfo    *match_info,
'                                      gint                 match_num);
' ========================================================================================
DECLARE FUNCTION g_match_info_fetch CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_fetch" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 , BYVAL LONG _                             ' gint                 match_num
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gboolean     g_match_info_fetch_pos   (const GMatchInfo    *match_info,
'                                       gint                 match_num,
'                                       gint                *start_pos,
'                                       gint                *end_pos);
' ========================================================================================
DECLARE FUNCTION g_match_info_fetch_pos CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_fetch_pos" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 , BYVAL LONG _                             ' gint                 match_num
 , BYREF LONG _                             ' gint                *start_pos
 , BYREF LONG _                             ' gint                *end_pos
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gchar       *g_match_info_fetch_named   (const GMatchInfo    *match_info,
'                                         const gchar         *name);
' ========================================================================================
DECLARE FUNCTION g_match_info_fetch_named CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_fetch_named" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 , BYREF ASCIIZ _                           ' const gchar         *name
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gboolean     g_match_info_fetch_named_pos   (const GMatchInfo    *match_info,
'                                             const gchar         *name,
'                                             gint                *start_pos,
'                                             gint                *end_pos);
' ========================================================================================
DECLARE FUNCTION g_match_info_fetch_named_pos CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_fetch_named_pos" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 , BYREF ASCIIZ _                           ' const gchar         *name
 , BYREF LONG _                             ' gint                *start_pos
 , BYREF LONG _                             ' gint                *end_pos
 ) AS DWORD                                 ' gboolean

' ========================================================================================
'gchar      **g_match_info_fetch_all   (const GMatchInfo    *match_info);
' ========================================================================================
DECLARE FUNCTION g_match_info_fetch_all CDECL LIB $GLIB_DLLNAME ALIAS "g_match_info_fetch_all" ( _
   BYVAL DWORD _                            ' const GMatchInfo    *match_info
 ) AS DWORD                                 ' gchar**

'G_END_DECLS

'#endif  /*  __G_REGEX_H__ */
#ENDIF   '  /*  __GREGEX_INC__ */
