'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_SCANNER_H__
'#define __G_SCANNER_H__

#IF NOT %DEF(%GSCANNER_INC)
    %GSCANNER_INC = 1

#INCLUDE ONCE "gdataset.inc"
#INCLUDE ONCE "ghash.inc"

'G_BEGIN_DECLS

'typedef struct _GScanner   GScanner;
'typedef struct _GScannerConfig   GScannerConfig;
'typedef union  _GTokenValue     GTokenValue;

'typedef void      (*GScannerMsgFunc)   (GScanner      *scanner,
'                   gchar          *message,
'                   gboolean   error);

'SUB GScannerMsgFunc (BYVAL scanner AS GScanner PTR, BYREF message AS ASCIIZ, BYVAL bError AS LONG)

'/* GScanner: Flexible lexical scanner for general purpose.
' */

'/* Character sets */
'#define G_CSET_A_2_Z   "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
'#define G_CSET_a_2_z   "abcdefghijklmnopqrstuvwxyz"
'#define G_CSET_DIGITS   "0123456789"
'#define G_CSET_LATINC   "\300\301\302\303\304\305\306"\
'         "\307\310\311\312\313\314\315\316\317\320"\
'         "\321\322\323\324\325\326"\
'         "\330\331\332\333\334\335\336"
'#define G_CSET_LATINS   "\337\340\341\342\343\344\345\346"\
'         "\347\350\351\352\353\354\355\356\357\360"\
'         "\361\362\363\364\365\366"\
'         "\370\371\372\373\374\375\376\377"

$G_CSET_A_2_Z      = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
$G_CSET_a_2_z_min  = "abcdefghijklmnopqrstuvwxyz"
$G_CSET_DIGITS     = "0123456789"
$G_CSET_LATINC     = "\300\301\302\303\304\305\306\307\310\311\312\313\314\315\316\317\320\321\322\323\324\325\326\330\331\332\333\334\335\336"
$G_CSET_LATINS     = "\337\340\341\342\343\344\345\346\347\350\351\352\353\354\355\356\357\360\361\362\363\364\365\366\370\371\372\373\374\375\376\377"

'/* Error types */
'typedef enum
'{
'  G_ERR_UNKNOWN,
'  G_ERR_UNEXP_EOF,
'  G_ERR_UNEXP_EOF_IN_STRING,
'  G_ERR_UNEXP_EOF_IN_COMMENT,
'  G_ERR_NON_DIGIT_IN_CONST,
'  G_ERR_DIGIT_RADIX,
'  G_ERR_FLOAT_RADIX,
'  G_ERR_FLOAT_MALFORMED
'} GErrorType;

%G_ERR_UNKNOWN              = 0
%G_ERR_UNEXP_EOF            = 1
%G_ERR_UNEXP_EOF_IN_STRING  = 2
%G_ERR_UNEXP_EOF_IN_COMMENT = 3
%G_ERR_NON_DIGIT_IN_CONST   = 4
%G_ERR_DIGIT_RADIX          = 5
%G_ERR_FLOAT_RADIX          = 6
%G_ERR_FLOAT_MALFORMED      = 7

'/* Token types */
'typedef enum
'{
'  G_TOKEN_EOF         =   0,

'  G_TOKEN_LEFT_PAREN      = '(',
'  G_TOKEN_RIGHT_PAREN      = ')',
'  G_TOKEN_LEFT_CURLY      = '{',
'  G_TOKEN_RIGHT_CURLY      = '}',
'  G_TOKEN_LEFT_BRACE      = '[',
'  G_TOKEN_RIGHT_BRACE      = ']',
'  G_TOKEN_EQUAL_SIGN      = '=',
'  G_TOKEN_COMMA         = ',',

'  G_TOKEN_NONE         = 256,

'  G_TOKEN_ERROR,

'  G_TOKEN_CHAR,
'  G_TOKEN_BINARY,
'  G_TOKEN_OCTAL,
'  G_TOKEN_INT,
'  G_TOKEN_HEX,
'  G_TOKEN_FLOAT,
'  G_TOKEN_STRING,

'  G_TOKEN_SYMBOL,
'  G_TOKEN_IDENTIFIER,
'  G_TOKEN_IDENTIFIER_NULL,

'  G_TOKEN_COMMENT_SINGLE,
'  G_TOKEN_COMMENT_MULTI,
'  G_TOKEN_LAST
'} GTokenType;

%G_TOKEN_EOF             =   0

$G_TOKEN_LEFT_PAREN      = "("
$G_TOKEN_RIGHT_PAREN     = ")"
$G_TOKEN_LEFT_CURLY      = "{"
$G_TOKEN_RIGHT_CURLY     = "}"
$G_TOKEN_LEFT_BRACE      = "["
$G_TOKEN_RIGHT_BRACE     = "]"
$G_TOKEN_EQUAL_SIGN      = "="
$G_TOKEN_COMMA           = ","

%G_TOKEN_NONE            = 256

%G_TOKEN_ERROR           = 257

%G_TOKEN_CHAR            = 258
%G_TOKEN_BINARY          = 259
%G_TOKEN_OCTAL           = 260
%G_TOKEN_INT             = 261
%G_TOKEN_HEX             = 262
%G_TOKEN_FLOAT           = 263
%G_TOKEN_STRING          = 264

%G_TOKEN_SYMBOL          = 265
%G_TOKEN_IDENTIFIER      = 266
%G_TOKEN_IDENTIFIER_NULL = 267

%G_TOKEN_COMMENT_SINGLE  = 268
%G_TOKEN_COMMENT_MULTI   = 269
%G_TOKEN_LAST            = 270

'union   _GTokenValue
'{
'  gpointer   v_symbol;
'  gchar     *v_identifier;
'  gulong     v_binary;
'  gulong     v_octal;
'  gulong     v_int;
'  guint64    v_int64;
'  gdouble    v_float;
'  gulong     v_hex;
'  gchar     *v_string;
'  gchar     *v_comment;
'  guchar     v_char;
'  guint      v_error;
'};

UNION GTokenValue
   v_symbol     AS DWORD
   v_identifier AS ASCIIZ PTR
   v_binary     AS DWORD
   v_octal      AS DWORD
   v_int        AS DWORD
   v_int64      AS QUAD
   v_float      AS DOUBLE
   v_hex        AS DWORD
   v_string     AS ASCIIZ PTR
   v_comment    AS ASCIIZ PTR
   v_char       AS BYTE
   v_error      AS DWORD
END UNION

'struct   _GScannerConfig
'{
'  /* Character sets
'   */
'  gchar      *cset_skip_characters;      /* default: " \t\n" */
'  gchar      *cset_identifier_first;
'  gchar      *cset_identifier_nth;
'  gchar      *cpair_comment_single;      /* default: "#\n" */

'  /* Should symbol lookup work case sensitive?
'   */
'  guint      case_sensitive : 1;

'  /* Boolean values to be adjusted "on the fly"
'   * to configure scanning behaviour.
'   */
'  guint      skip_comment_multi : 1;      /* C like comment */
'  guint      skip_comment_single : 1;   /* single line comment */
'  guint      scan_comment_multi : 1;      /* scan multi line comments? */
'  guint      scan_identifier : 1;
'  guint      scan_identifier_1char : 1;
'  guint      scan_identifier_NULL : 1;
'  guint      scan_symbols : 1;
'  guint      scan_binary : 1;
'  guint      scan_octal : 1;
'  guint      scan_float : 1;
'  guint      scan_hex : 1;         /* `0x0ff0' */
'  guint      scan_hex_dollar : 1;      /* `$0ff0' */
'  guint      scan_string_sq : 1;      /* string: 'anything' */
'  guint      scan_string_dq : 1;      /* string: "\\-escapes!\n" */
'  guint      numbers_2_int : 1;      /* bin, octal, hex => int */
'  guint      int_2_float : 1;      /* int => G_TOKEN_FLOAT? */
'  guint      identifier_2_string : 1;
'  guint      char_2_token : 1;      /* return G_TOKEN_CHAR? */
'  guint      symbol_2_token : 1;
'  guint      scope_0_fallback : 1;      /* try scope 0 on lookups? */
'  guint      store_int64 : 1;       /* use value.v_int64 rather than v_int */
'  guint      padding_dummy;
'};

TYPE GScannerConfig
   cset_skip_characters  AS ASCIIZ PTR
   cset_identifier_first AS ASCIIZ PTR
   cset_identifier_nth   AS ASCIIZ PTR
   cpair_comment_single  AS ASCIIZ PTR
   case_sensitive        AS BIT * 1 IN DWORD
   skip_comment_multi    AS BIT * 1
   skip_comment_single   AS BIT * 1
   scan_comment_multi    AS BIT * 1
   scan_identifier       AS BIT * 1
   scan_identifier_1char AS BIT * 1
   scan_identifier_NULL  AS BIT * 1
   scan_symbols          AS BIT * 1
   scan_binary           AS BIT * 1
   scan_octal            AS BIT * 1
   scan_float            AS BIT * 1
   scan_hex              AS BIT * 1
   scan_hex_dollar       AS BIT * 1
   scan_string_sq        AS BIT * 1
   scan_string_dq        AS BIT * 1
   numbers_2_int         AS BIT * 1
   int_2_float           AS BIT * 1
   identifier_2_string   AS BIT * 1
   char_2_token          AS BIT * 1
   symbol_2_token        AS BIT * 1
   scope_0_fallback      AS BIT * 1
   store_int64           AS BIT * 1
   padding_dummy         AS BIT * 10
END TYPE

'struct   _GScanner
'{
'  /* unused fields */
'  gpointer      user_data;
'  guint         max_parse_errors;

'  /* g_scanner_error() increments this field */
'  guint         parse_errors;

'  /* name of input stream, featured by the default message handler */
'  const gchar      *input_name;

'  /* quarked data */
'  GData         *qdata;

'  /* link into the scanner configuration */
'  GScannerConfig   *config;

'  /* fields filled in after g_scanner_get_next_token() */
'  GTokenType      token;
'  GTokenValue      value;
'  guint         line;
'  guint         position;

'  /* fields filled in after g_scanner_peek_next_token() */
'  GTokenType      next_token;
'  GTokenValue      next_value;
'  guint         next_line;
'  guint         next_position;

'  /* to be considered private */
'  GHashTable      *symbol_table;
'  gint         input_fd;
'  const gchar      *text;
'  const gchar      *text_end;
'  gchar         *buffer;
'  guint         scope_id;

'  /* handler function for _warn and _error */
'  GScannerMsgFunc   msg_handler;
'};

TYPE GScanner
   user_data        AS DWORD
   max_parse_errors AS DWORD
   parse_errors     AS DWORD
   input_name       AS ASCIIZ PTR
   qdata            AS DWORD
   config           AS GScannerConfig PTR
   token            AS LONG
   value            AS GTokenValue
   line             AS DWORD
   position         AS DWORD
   next_token       AS LONG
   next_value       AS GTokenValue
   next_line        AS DWORD
   next_position    AS DWORD
   symbol_table     AS DWORD
   input_fd         AS LONG
   text             AS ASCIIZ PTR
   text_end         AS ASCIIZ PTR
   buffer           AS ASCIIZ PTR
   scope_id         AS DWORD
   msg_handler      AS DWORD
END TYPE

' ========================================================================================
'GScanner*   g_scanner_new         (const GScannerConfig *config_templ);
' ========================================================================================
DECLARE FUNCTION g_scanner_new CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_new" ( _
   BYVAL GScannerConfig PTR _               ' const GScannerConfig *config_templ
 ) AS DWORD                                 ' GScanner*

' ========================================================================================
'void      g_scanner_destroy      (GScanner   *scanner);
' ========================================================================================
DECLARE SUB g_scanner_destroy CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_destroy" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 )                                          ' void

' ========================================================================================
'void      g_scanner_input_file      (GScanner   *scanner,
'                                     gint      input_fd);
' ========================================================================================
DECLARE SUB g_scanner_input_file CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_input_file" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 , BYVAL LONG _                             ' gint      input_fd
 )                                          ' void

' ========================================================================================
'void      g_scanner_sync_file_offset   (GScanner   *scanner);
' ========================================================================================
DECLARE SUB g_scanner_sync_file_offset CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_sync_file_offset" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 )                                          ' void

' ========================================================================================
'void      g_scanner_input_text      (GScanner   *scanner,
'                                     const       gchar   *text,
'                                     guint       text_len);
' ========================================================================================
DECLARE SUB g_scanner_input_text CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_input_text" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 , BYREF ASCIIZ _                           ' const       gchar   *text
 , BYVAL DWORD _                            ' guint       text_len
 )                                          ' void

' ========================================================================================
'GTokenType   g_scanner_get_next_token   (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_get_next_token CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_get_next_token" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS LONG                                  ' GTokenType

' ========================================================================================
'GTokenType   g_scanner_peek_next_token   (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_peek_next_token CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_peek_next_token" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS LONG                                  ' GTokenType

' ========================================================================================
'GTokenType   g_scanner_cur_token      (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_cur_token CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_cur_token" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS LONG                                  ' GTokenType

' ========================================================================================
'GTokenValue   g_scanner_cur_value      (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_cur_value CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_cur_value" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS DWORD                                 ' GTokenValue

' ========================================================================================
'guint      g_scanner_cur_line      (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_cur_line CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_cur_line" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS DWORD                                 ' guint

' ========================================================================================
'guint      g_scanner_cur_position      (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_cur_position CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_cur_position" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS DWORD                                 ' guint

' ========================================================================================
'gboolean   g_scanner_eof         (GScanner   *scanner);
' ========================================================================================
DECLARE FUNCTION g_scanner_eof CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_eof" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 ) AS LONG                                  ' gboolean

' ========================================================================================
'guint      g_scanner_set_scope      (GScanner   *scanner,
'                                     guint       scope_id);
' ========================================================================================
DECLARE FUNCTION g_scanner_set_scope CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_set_scope" ( _
   BYVAL GScanner PTR _                     ' GScanner   *scanner
 , BYVAL DWORD _                            ' guint       scope_id
 ) AS DWORD                                 ' guint

' ========================================================================================
'void      g_scanner_scope_add_symbol   (GScanner    *scanner,
'                                        guint        scope_id,
'                                        const gchar *symbol,
'                                        gpointer     value);
' ========================================================================================
DECLARE SUB g_scanner_scope_add_symbol CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_scope_add_symbol" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL DWORD _                            ' guint        scope_id
 , BYREF ASCIIZ _                           ' const gchar *symbol
 , BYVAL DWORD _                            ' gpointer     value
 )                                          ' void

' ========================================================================================
'void      g_scanner_scope_remove_symbol   (GScanner    *scanner,
'                                           guint        scope_id,
'                                           const gchar *symbol);
' ========================================================================================
DECLARE SUB g_scanner_scope_remove_symbol CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_scope_remove_symbol" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL DWORD _                            ' guint        scope_id
 , BYREF ASCIIZ _                           ' const gchar *symbol
 )                                          ' void

' ========================================================================================
'gpointer   g_scanner_scope_lookup_symbol   (GScanner    *scanner,
'                                            guint        scope_id,
'                                            const gchar *symbol);
' ========================================================================================
DECLARE FUNCTION g_scanner_scope_lookup_symbol CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_scope_lookup_symbol" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL DWORD _                            ' guint        scope_id
 , BYREF ASCIIZ _                           ' const gchar *symbol
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'void      g_scanner_scope_foreach_symbol   (GScanner   *scanner,
'                                            guint       scope_id,
'                                            GHFunc      func,
'                                            gpointer    user_data);
' ========================================================================================
DECLARE SUB g_scanner_scope_foreach_symbol CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_scope_foreach_symbol" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL DWORD _                            ' guint        scope_id
 , BYVAL DWORD _                            ' GHFunc       func
 , BYVAL DWORD _                            ' gpointer     user_data
 )                                          ' void

' ========================================================================================
'gpointer   g_scanner_lookup_symbol      (GScanner    *scanner,
'                                         const gchar *symbol);
' ========================================================================================
DECLARE FUNCTION g_scanner_lookup_symbol CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_lookup_symbol" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL DWORD _                            ' guint        scope_id
 ) AS DWORD                                 ' gpointer

' ========================================================================================
'void      g_scanner_unexp_token      (GScanner    *scanner,
'                                      GTokenType   expected_token,
'                                      const gchar *identifier_spec,
'                                      const gchar *symbol_spec,
'                                      const gchar *symbol_name,
'                                      const gchar *message,
'                                      gint         is_error);
' ========================================================================================
DECLARE SUB g_scanner_unexp_token CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_unexp_token" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYVAL LONG _                             ' GTokenType   expected_token
 , BYREF ASCIIZ _                           ' const gchar *identifier_spec
 , BYREF ASCIIZ _                           ' const gchar *symbol_spec
 , BYREF ASCIIZ _                           ' const gchar *symbol_name
 , BYREF ASCIIZ _                           ' const gchar *message
 , BYVAL LONG _                             ' gint         is_error
 )                                          ' void

' ========================================================================================
'void      g_scanner_error         (GScanner    *scanner,
'                                   const gchar *format,
'                                   ...) G_GNUC_PRINTF (2,3);
' ========================================================================================
DECLARE SUB g_scanner_error CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_error" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYREF ASCIIZ _                           ' const gchar *format
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 )                                          ' void

' ========================================================================================
'void      g_scanner_warn         (GScanner    *scanner,
'                                  const gchar *format,
'                                  ...) G_GNUC_PRINTF (2,3);
' ========================================================================================
DECLARE SUB g_scanner_warn CDECL LIB $GLIB_DLLNAME ALIAS "g_scanner_warn" ( _
   BYVAL GScanner PTR _                     ' GScanner    *scanner
 , BYREF ASCIIZ _                           ' const gchar *format
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 )                                          ' void

'#ifndef G_DISABLE_DEPRECATED

'/* keep downward source compatibility */
'#define      g_scanner_add_symbol( scanner, symbol, value )   G_STMT_START { \
'  g_scanner_scope_add_symbol ((scanner), 0, (symbol), (value)); \
'} G_STMT_END

MACRO g_scanner_add_symbol(scanner, symbol, value) = g_scanner_scope_add_symbol(scanner, 0, symbol, value)

'#define      g_scanner_remove_symbol( scanner, symbol )   G_STMT_START { \
'  g_scanner_scope_remove_symbol ((scanner), 0, (symbol)); \
'} G_STMT_END

MACRO g_scanner_remove_symbol(scanner, symbol) = g_scanner_scope_remove_symbol(scanner, 0, symbol)

'#define      g_scanner_foreach_symbol( scanner, func, data )   G_STMT_START { \
'  g_scanner_scope_foreach_symbol ((scanner), 0, (func), (data)); \
'} G_STMT_END

MACRO g_scanner_foreach_symbol(scanner, func, pdata) = g_scanner_scope_foreach_symbol(scanner, 0, func, pdata)

'/* The following two functions are deprecated and will be removed in
' * the next major release. They do no good. */
'#define g_scanner_freeze_symbol_table(scanner) ((void)0)
'#define g_scanner_thaw_symbol_table(scanner) ((void)0)

'#endif /* G_DISABLE_DEPRECATED */

'G_END_DECLS

'#endif /* __G_SCANNER_H__ */
#ENDIF   ' /* __G_SCANNER_H__ */
