'/* GLIB - Library of useful routines for C programming
' * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
' *
' * This library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public
' * License as published by the Free Software Foundation; either
' * version 2 of the License, or (at your option) any later version.
' *
' * This library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with this library; if not, write to the
' * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' * Boston, MA 02111-1307, USA.
' */

'/*
' * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
' * file for a list of people on the GLib Team.  See the ChangeLog
' * files for a list of changes.  These files are distributed with
' * GLib at ftp://ftp.gtk.org/pub/gtk/.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_STRING_H__
'#define __G_STRING_H__

#IF NOT %DEF(%GSTRING_INC)
    %GSTRING_INC = 1

#INCLUDE ONCE "gtypes.inc"
#INCLUDE ONCE "gunicode.inc"
#INCLUDE ONCE "gutils.inc"    ' /* for G_CAN_INLINE */

'G_BEGIN_DECLS

'typedef struct _GString      GString;
'typedef struct _GStringChunk   GStringChunk;

'struct _GString
'{
'  gchar  *str;
'  gsize len;
'  gsize allocated_len;
'};

TYPE GString
   str           AS ASCIIZ PTR
   len           AS DWORD
   allocated_len AS DWORD
END TYPE

'/* String Chunks
' */

' ========================================================================================
'GStringChunk* g_string_chunk_new      (gsize size);
' ========================================================================================
DECLARE FUNCTION g_string_chunk_new CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_new" ( _
   BYVAL DWORD _                            ' gsize size
 ) AS DWORD                                 ' GStringChunk*

' ========================================================================================
'void         g_string_chunk_free      (GStringChunk *chunk);
' ========================================================================================
DECLARE SUB g_string_chunk_free CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_free" ( _
   BYVAL DWORD _                            ' GStringChunk *chunk
 )                                          ' void

' ========================================================================================
'void         g_string_chunk_clear      (GStringChunk *chunk);
' ========================================================================================
DECLARE SUB g_string_chunk_clear CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_clear" ( _
   BYVAL DWORD _                            ' GStringChunk *chunk
 )                                          ' void

' ========================================================================================
'gchar*         g_string_chunk_insert      (GStringChunk *chunk,
'                                           const gchar    *string);
' ========================================================================================
DECLARE FUNCTION g_string_chunk_insert CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_insert" ( _
   BYVAL DWORD _                            ' GStringChunk *chunk
 , BYREF ASCIIZ _                           ' const gchar    *string
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar*         g_string_chunk_insert_len      (GStringChunk *chunk,
'                                               const gchar  *string,
'                                               gssize        len);
' ========================================================================================
DECLARE FUNCTION g_string_chunk_insert_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_insert_len" ( _
   BYVAL DWORD _                            ' GStringChunk *chunk
 , BYREF ANY _                              ' const gchar  *string
 , BYVAL LONG _                             ' gssize        len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar*         g_string_chunk_insert_const  (GStringChunk *chunk,
'                                             const gchar    *string);
' ========================================================================================
DECLARE FUNCTION g_string_chunk_insert_const CDECL LIB $GLIB_DLLNAME ALIAS "g_string_chunk_insert_const" ( _
   BYVAL DWORD _                            ' GStringChunk *chunk
 , BYREF ASCIIZ _                           ' const gchar  *string
 ) AS DWORD                                 ' gchar*


'/* Strings
' */

' ========================================================================================
'GString*     g_string_new           (const gchar    *init);
' ========================================================================================
DECLARE FUNCTION g_string_new CDECL LIB $GLIB_DLLNAME ALIAS "g_string_new" ( _
   BYREF ASCIIZ _                           ' const gchar  *init
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_new_len           (const gchar     *init,
'                                         gssize           len);
' ========================================================================================
DECLARE FUNCTION g_string_new_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_new_len" ( _
   BYREF ANY _                              ' const gchar  *init
 , BYVAL LONG _                             ' gssize        len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_sized_new         (gsize            dfl_size);
' ========================================================================================
DECLARE FUNCTION g_string_sized_new CDECL LIB $GLIB_DLLNAME ALIAS "g_string_sized_new" ( _
   BYVAL DWORD _                            ' gsize            dfl_size
 ) AS DWORD                                 ' GString*

' ========================================================================================
'gchar*        g_string_free           (GString    *string,
'                                       gboolean     free_segment);
' ========================================================================================
DECLARE FUNCTION g_string_free CDECL LIB $GLIB_DLLNAME ALIAS "g_string_free" ( _
   BYVAL GString PTR _                      ' GString    *string
 , BYVAL LONG _                             ' gboolean     free_segment
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gboolean     g_string_equal             (const GString    *v,
'                                         const GString    *v2);
' ========================================================================================
DECLARE FUNCTION g_string_equal CDECL LIB $GLIB_DLLNAME ALIAS "g_string_equal" ( _
   BYVAL GString PTR _                      ' const GString    *v
 , BYVAL GString PTR _                      ' const GString    *v2
 ) AS LONG                                  ' gboolean

' ========================================================================================
'guint        g_string_hash              (const GString   *str);
' ========================================================================================
DECLARE FUNCTION g_string_hash CDECL LIB $GLIB_DLLNAME ALIAS "g_string_hash" ( _
   BYVAL GString PTR _                      ' const GString   *str
 ) AS DWORD                                 ' guint

' ========================================================================================
'GString*     g_string_assign            (GString     *string,
'                                         const gchar *rval);
' ========================================================================================
DECLARE FUNCTION g_string_assign CDECL LIB $GLIB_DLLNAME ALIAS "g_string_assign" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *rval
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_truncate          (GString    *string,
'                                         gsize       len);
' ========================================================================================
DECLARE FUNCTION g_string_truncate CDECL LIB $GLIB_DLLNAME ALIAS "g_string_truncate" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gsize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_set_size          (GString         *string,
'                                         gsize            len);
' ========================================================================================
DECLARE FUNCTION g_string_set_size CDECL LIB $GLIB_DLLNAME ALIAS "g_string_set_size" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gsize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_insert_len        (GString         *string,
'                                         gssize           pos,
'                                         const gchar     *val,
'                                         gssize           len);
' ========================================================================================
DECLARE FUNCTION g_string_insert_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_insert_len" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL LONG _                             ' gssize       pos
 , BYREF ANY _                              ' const gchar *val
 , BYVAL LONG _                             ' gssize      len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_append            (GString     *string,
'                                         const gchar *val);
' ========================================================================================
DECLARE FUNCTION g_string_append CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *val
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_append_len        (GString     *string,
'                                         const gchar *val,
'                                         gssize       len);
' ========================================================================================
DECLARE FUNCTION g_string_append_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_len" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ANY _                              ' const gchar *val
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_append_c          (GString    *string,
'                                         gchar       c);
' ========================================================================================
DECLARE FUNCTION g_string_append_c CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_c" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL BYTE _                             ' gchar        c
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_append_unichar    (GString    *string,
'                                         gunichar    wc);
' ========================================================================================
DECLARE FUNCTION g_string_append_unichar CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_unichar" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gunichar     wc
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_prepend           (GString     *string,
'                                         const gchar *val);
' ========================================================================================
DECLARE FUNCTION g_string_prepend CDECL LIB $GLIB_DLLNAME ALIAS "g_string_prepend" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *val
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_prepend_c         (GString    *string,
'                                         gchar       c);
' ========================================================================================
DECLARE FUNCTION g_string_prepend_c CDECL LIB $GLIB_DLLNAME ALIAS "g_string_prepend_c" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL BYTE _                             ' gchar        c
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_prepend_unichar   (GString    *string,
'                                         gunichar    wc);
' ========================================================================================
DECLARE FUNCTION g_string_prepend_unichar CDECL LIB $GLIB_DLLNAME ALIAS "g_string_prepend_unichar" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gunichar     wc
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_prepend_len       (GString     *string,
'                                         const gchar *val,
'                                         gssize       len);
' ========================================================================================
DECLARE FUNCTION g_string_prepend_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_prepend_len" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ANY _                              ' const gchar *val
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_insert            (GString     *string,
'                                         gssize       pos,
'                                         const gchar *val);
' ========================================================================================
DECLARE FUNCTION g_string_insert CDECL LIB $GLIB_DLLNAME ALIAS "g_string_insert" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL LONG _                             ' gssize       pos
 , BYREF ASCIIZ _                           ' const gchar *val
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_insert_c          (GString    *string,
'                                         gssize      pos,
'                                         gchar       c);
' ========================================================================================
DECLARE FUNCTION g_string_insert_c CDECL LIB $GLIB_DLLNAME ALIAS "g_string_insert_c" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL LONG _                             ' gssize       pos
 , BYVAL BYTE _                             ' gchar        c
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_insert_unichar    (GString    *string,
'                                         gssize      pos,
'                                         gunichar    wc);
' ========================================================================================
DECLARE FUNCTION g_string_insert_unichar CDECL LIB $GLIB_DLLNAME ALIAS "g_string_insert_unichar" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL LONG _                             ' gssize       pos
 , BYVAL DWORD _                            ' gunichar     wc
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_overwrite         (GString     *string,
'                                         gsize        pos,
'                                         const gchar *val);
' ========================================================================================
DECLARE FUNCTION g_string_overwrite CDECL LIB $GLIB_DLLNAME ALIAS "g_string_overwrite" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gsize        pos
 , BYREF ASCIIZ _                           ' const gchar *val
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_overwrite_len     (GString     *string,
'                                         gsize        pos,
'                                         const gchar *val,
'                                         gssize       len);
' ========================================================================================
DECLARE FUNCTION g_string_overwrite_len CDECL LIB $GLIB_DLLNAME ALIAS "g_string_overwrite_len" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL DWORD _                            ' gsize        pos
 , BYREF ANY _                              ' const gchar *val
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_erase           (GString    *string,
'                                       gssize      pos,
'                                       gssize      len);
' ========================================================================================
DECLARE FUNCTION g_string_erase CDECL LIB $GLIB_DLLNAME ALIAS "g_string_erase" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYVAL LONG _                             ' gssize       pos
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_ascii_down        (GString    *string);
' ========================================================================================
DECLARE FUNCTION g_string_ascii_down CDECL LIB $GLIB_DLLNAME ALIAS "g_string_ascii_down" ( _
   BYVAL GString PTR _                      ' GString     *string
 ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_ascii_up          (GString    *string);
' ========================================================================================
DECLARE FUNCTION g_string_ascii_up CDECL LIB $GLIB_DLLNAME ALIAS "g_string_ascii_up" ( _
   BYVAL GString PTR _                      ' GString     *string
 ) AS DWORD                                 ' GString*

' ========================================================================================
'void         g_string_vprintf           (GString     *string,
'                                         const gchar *format,
'                                         va_list      args);
' ========================================================================================
DECLARE SUB g_string_vprintf CDECL LIB $GLIB_DLLNAME ALIAS "g_string_vprintf" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *format
 , BYREF ANY _                              ' va_list      args
 )                                          ' void

' ========================================================================================
'void         g_string_printf            (GString    *string,
'                                         const gchar    *format,
'                                         ...) G_GNUC_PRINTF (2, 3);
' ========================================================================================
DECLARE SUB g_string_printf CDECL LIB $GLIB_DLLNAME ALIAS "g_string_printf" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *format
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 )                                          ' void

' ========================================================================================
'void         g_string_append_vprintf    (GString     *string,
'                                         const gchar *format,
'                                         va_list      args);
' ========================================================================================
DECLARE SUB g_string_append_vprintf CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_vprintf" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *format
 , BYREF ANY _                              ' va_list      args
 )                                          ' void

' ========================================================================================
'void         g_string_append_printf     (GString     *string,
'                                         const gchar *format,
'                                         ...) G_GNUC_PRINTF (2, 3);
' ========================================================================================
DECLARE SUB g_string_append_printf CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_printf" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const gchar *format
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 , OPTIONAL BYREF ANY _
 )                                          ' void

' ========================================================================================
'GString *    g_string_append_uri_escaped(GString         *string,
'                                         const char      *unescaped,
'                                         const char      *reserved_chars_allowed,
'                                         gboolean         allow_utf8);
' ========================================================================================
DECLARE FUNCTION g_string_append_uri_escaped CDECL LIB $GLIB_DLLNAME ALIAS "g_string_append_uri_escaped" ( _
   BYVAL GString PTR _                      ' GString     *string
 , BYREF ASCIIZ _                           ' const char  *unescaped
 , BYREF ASCIIZ _                           ' const char  *reserved_chars_allowed
 , BYVAL LONG _                             ' gboolean     allow_utf8
 ) AS DWORD                                 ' GString*

'/* -- optimize g_strig_append_c --- */
'#ifdef G_CAN_INLINE
'static inline GString*
'g_string_append_c_inline (GString *gstring,
'                          gchar    c)
'{
'  if (gstring->len + 1 < gstring->allocated_len)
'    {
'      gstring->str[gstring->len++] = c;
'      gstring->str[gstring->len] = 0;
'    }
'  else
'    g_string_insert_c (gstring, -1, c);
'  return gstring;
'}
'#define g_string_append_c(gstr,c)       g_string_append_c_inline (gstr, c)
'#endif /* G_CAN_INLINE */


'#ifndef G_DISABLE_DEPRECATED

'/* The following two functions are deprecated and will be removed in
' * the next major release. They use the locale-specific tolower and
' * toupper, which is almost never the right thing.
' */

' ========================================================================================
'GString*     g_string_down              (GString    *string);
' ========================================================================================
'DECLARE FUNCTION g_string_down CDECL LIB $GLIB_DLLNAME ALIAS "g_string_down" ( _
'   BYVAL GString PTR _                      ' GString     *string
' ) AS DWORD                                 ' GString*

' ========================================================================================
'GString*     g_string_up                (GString    *string);
' ========================================================================================
'DECLARE FUNCTION g_string_up CDECL LIB $GLIB_DLLNAME ALIAS "g_string_up" ( _
'   BYVAL GString PTR _                      ' GString     *string
' ) AS DWORD                                 ' GString*

'/* These aliases are included for compatibility. */
'#define   g_string_sprintf   g_string_printf
'#define   g_string_sprintfa   g_string_append_printf

'#endif /* G_DISABLE_DEPRECATED */

'G_END_DECLS

'#endif /* __G_STRING_H__ */
#ENDIF   ' /* __GSTRING_INC__ */
