'/* gunicode.h - Unicode manipulation functions
' *
' *  Copyright (C) 1999, 2000 Tom Tromey
' *  Copyright 2000, 2005 Red Hat, Inc.
' *
' * The Gnome Library is free software; you can redistribute it and/or
' * modify it under the terms of the GNU Lesser General Public License as
' * published by the Free Software Foundation; either version 2 of the
' * License, or (at your option) any later version.
' *
' * The Gnome Library is distributed in the hope that it will be useful,
' * but WITHOUT ANY WARRANTY; without even the implied warranty of
' * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
' * Lesser General Public License for more details.
' *
' * You should have received a copy of the GNU Lesser General Public
' * License along with the Gnome Library; see the file COPYING.LIB.  If not,
' * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
' *   Boston, MA 02111-1307, USA.
' */

'#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
'#error "Only <glib.h> can be included directly."
'#endif

'#ifndef __G_UNICODE_H__
'#define __G_UNICODE_H__

#IF NOT %DEF(%GUNICODE_INC)
    %GUNICODE_INC = 1

#INCLUDE ONCE "gerror.inc"
#INCLUDE ONCE "gtypes.inc"

'G_BEGIN_DECLS

'typedef guint32 gunichar;
'typedef guint16 gunichar2;

'/* These are the possible character classifications.
' * See http://www.unicode.org/Public/UNIDATA/UCD.html#General_Category_Values
' */
'typedef enum
'{
'  G_UNICODE_CONTROL,
'  G_UNICODE_FORMAT,
'  G_UNICODE_UNASSIGNED,
'  G_UNICODE_PRIVATE_USE,
'  G_UNICODE_SURROGATE,
'  G_UNICODE_LOWERCASE_LETTER,
'  G_UNICODE_MODIFIER_LETTER,
'  G_UNICODE_OTHER_LETTER,
'  G_UNICODE_TITLECASE_LETTER,
'  G_UNICODE_UPPERCASE_LETTER,
'  G_UNICODE_COMBINING_MARK,
'  G_UNICODE_ENCLOSING_MARK,
'  G_UNICODE_NON_SPACING_MARK,
'  G_UNICODE_DECIMAL_NUMBER,
'  G_UNICODE_LETTER_NUMBER,
'  G_UNICODE_OTHER_NUMBER,
'  G_UNICODE_CONNECT_PUNCTUATION,
'  G_UNICODE_DASH_PUNCTUATION,
'  G_UNICODE_CLOSE_PUNCTUATION,
'  G_UNICODE_FINAL_PUNCTUATION,
'  G_UNICODE_INITIAL_PUNCTUATION,
'  G_UNICODE_OTHER_PUNCTUATION,
'  G_UNICODE_OPEN_PUNCTUATION,
'  G_UNICODE_CURRENCY_SYMBOL,
'  G_UNICODE_MODIFIER_SYMBOL,
'  G_UNICODE_MATH_SYMBOL,
'  G_UNICODE_OTHER_SYMBOL,
'  G_UNICODE_LINE_SEPARATOR,
'  G_UNICODE_PARAGRAPH_SEPARATOR,
'  G_UNICODE_SPACE_SEPARATOR
'} GUnicodeType;

%G_UNICODE_CONTROL             = 0
%G_UNICODE_FORMAT              = 1
%G_UNICODE_UNASSIGNED          = 2
%G_UNICODE_PRIVATE_USE         = 3
%G_UNICODE_SURROGATE           = 4
%G_UNICODE_LOWERCASE_LETTER    = 5
%G_UNICODE_MODIFIER_LETTER     = 6
%G_UNICODE_OTHER_LETTER        = 7
%G_UNICODE_TITLECASE_LETTER    = 8
%G_UNICODE_UPPERCASE_LETTER    = 9
%G_UNICODE_COMBINING_MARK      = 10
%G_UNICODE_ENCLOSING_MARK      = 11
%G_UNICODE_NON_SPACING_MARK    = 12
%G_UNICODE_DECIMAL_NUMBER      = 13
%G_UNICODE_LETTER_NUMBER       = 14
%G_UNICODE_OTHER_NUMBER        = 15
%G_UNICODE_CONNECT_PUNCTUATION = 16
%G_UNICODE_DASH_PUNCTUATION    = 17
%G_UNICODE_CLOSE_PUNCTUATION   = 18
%G_UNICODE_FINAL_PUNCTUATION   = 19
%G_UNICODE_INITIAL_PUNCTUATION = 20
%G_UNICODE_OTHER_PUNCTUATION   = 21
%G_UNICODE_OPEN_PUNCTUATION    = 22
%G_UNICODE_CURRENCY_SYMBOL     = 23
%G_UNICODE_MODIFIER_SYMBOL     = 24
%G_UNICODE_MATH_SYMBOL         = 25
%G_UNICODE_OTHER_SYMBOL        = 26
%G_UNICODE_LINE_SEPARATOR      = 27
%G_UNICODE_PARAGRAPH_SEPARATOR = 28
%G_UNICODE_SPACE_SEPARATOR     = 29

'/* These are the possible line break classifications.
' * Note that new types may be added in the future.
' * Implementations may regard unknown values like G_UNICODE_BREAK_UNKNOWN
' * See http://www.unicode.org/unicode/reports/tr14/
' */
'typedef enum
'{
'  G_UNICODE_BREAK_MANDATORY,
'  G_UNICODE_BREAK_CARRIAGE_RETURN,
'  G_UNICODE_BREAK_LINE_FEED,
'  G_UNICODE_BREAK_COMBINING_MARK,
'  G_UNICODE_BREAK_SURROGATE,
'  G_UNICODE_BREAK_ZERO_WIDTH_SPACE,
'  G_UNICODE_BREAK_INSEPARABLE,
'  G_UNICODE_BREAK_NON_BREAKING_GLUE,
'  G_UNICODE_BREAK_CONTINGENT,
'  G_UNICODE_BREAK_SPACE,
'  G_UNICODE_BREAK_AFTER,
'  G_UNICODE_BREAK_BEFORE,
'  G_UNICODE_BREAK_BEFORE_AND_AFTER,
'  G_UNICODE_BREAK_HYPHEN,
'  G_UNICODE_BREAK_NON_STARTER,
'  G_UNICODE_BREAK_OPEN_PUNCTUATION,
'  G_UNICODE_BREAK_CLOSE_PUNCTUATION,
'  G_UNICODE_BREAK_QUOTATION,
'  G_UNICODE_BREAK_EXCLAMATION,
'  G_UNICODE_BREAK_IDEOGRAPHIC,
'  G_UNICODE_BREAK_NUMERIC,
'  G_UNICODE_BREAK_INFIX_SEPARATOR,
'  G_UNICODE_BREAK_SYMBOL,
'  G_UNICODE_BREAK_ALPHABETIC,
'  G_UNICODE_BREAK_PREFIX,
'  G_UNICODE_BREAK_POSTFIX,
'  G_UNICODE_BREAK_COMPLEX_CONTEXT,
'  G_UNICODE_BREAK_AMBIGUOUS,
'  G_UNICODE_BREAK_UNKNOWN,
'  G_UNICODE_BREAK_NEXT_LINE,
'  G_UNICODE_BREAK_WORD_JOINER,
'  G_UNICODE_BREAK_HANGUL_L_JAMO,
'  G_UNICODE_BREAK_HANGUL_V_JAMO,
'  G_UNICODE_BREAK_HANGUL_T_JAMO,
'  G_UNICODE_BREAK_HANGUL_LV_SYLLABLE,
'  G_UNICODE_BREAK_HANGUL_LVT_SYLLABLE
'} GUnicodeBreakType;

%G_UNICODE_BREAK_MANDATORY           = 0
%G_UNICODE_BREAK_CARRIAGE_RETURN     = 1
%G_UNICODE_BREAK_LINE_FEED           = 2
%G_UNICODE_BREAK_COMBINING_MARK      = 3
%G_UNICODE_BREAK_SURROGATE           = 4
%G_UNICODE_BREAK_ZERO_WIDTH_SPACE    = 5
%G_UNICODE_BREAK_INSEPARABLE         = 6
%G_UNICODE_BREAK_NON_BREAKING_GLUE   = 7
%G_UNICODE_BREAK_CONTINGENT          = 8
%G_UNICODE_BREAK_SPACE               = 9
%G_UNICODE_BREAK_AFTER               = 10
%G_UNICODE_BREAK_BEFORE              = 11
%G_UNICODE_BREAK_BEFORE_AND_AFTER    = 12
%G_UNICODE_BREAK_HYPHEN              = 13
%G_UNICODE_BREAK_NON_STARTER         = 14
%G_UNICODE_BREAK_OPEN_PUNCTUATION    = 15
%G_UNICODE_BREAK_CLOSE_PUNCTUATION   = 16
%G_UNICODE_BREAK_QUOTATION           = 17
%G_UNICODE_BREAK_EXCLAMATION         = 18
%G_UNICODE_BREAK_IDEOGRAPHIC         = 19
%G_UNICODE_BREAK_NUMERIC             = 20
%G_UNICODE_BREAK_INFIX_SEPARATOR     = 21
%G_UNICODE_BREAK_SYMBOL              = 22
%G_UNICODE_BREAK_ALPHABETIC          = 23
%G_UNICODE_BREAK_PREFIX              = 24
%G_UNICODE_BREAK_POSTFIX             = 25
%G_UNICODE_BREAK_COMPLEX_CONTEXT     = 26
%G_UNICODE_BREAK_AMBIGUOUS           = 27
%G_UNICODE_BREAK_UNKNOWN             = 28
%G_UNICODE_BREAK_NEXT_LINE           = 29
%G_UNICODE_BREAK_WORD_JOINER         = 30
%G_UNICODE_BREAK_HANGUL_L_JAMO       = 31
%G_UNICODE_BREAK_HANGUL_V_JAMO       = 32
%G_UNICODE_BREAK_HANGUL_T_JAMO       = 33
%G_UNICODE_BREAK_HANGUL_LV_SYLLABLE  = 34
%G_UNICODE_BREAK_HANGUL_LVT_SYLLABLE = 35

'typedef enum
'{                         /* ISO 15924 code */
'  G_UNICODE_SCRIPT_INVALID_CODE = -1,
'  G_UNICODE_SCRIPT_COMMON       = 0,   /* Zyyy */
'  G_UNICODE_SCRIPT_INHERITED,          /* Qaai */
'  G_UNICODE_SCRIPT_ARABIC,             /* Arab */
'  G_UNICODE_SCRIPT_ARMENIAN,           /* Armn */
'  G_UNICODE_SCRIPT_BENGALI,            /* Beng */
'  G_UNICODE_SCRIPT_BOPOMOFO,           /* Bopo */
'  G_UNICODE_SCRIPT_CHEROKEE,           /* Cher */
'  G_UNICODE_SCRIPT_COPTIC,             /* Qaac */
'  G_UNICODE_SCRIPT_CYRILLIC,           /* Cyrl (Cyrs) */
'  G_UNICODE_SCRIPT_DESERET,            /* Dsrt */
'  G_UNICODE_SCRIPT_DEVANAGARI,         /* Deva */
'  G_UNICODE_SCRIPT_ETHIOPIC,           /* Ethi */
'  G_UNICODE_SCRIPT_GEORGIAN,           /* Geor (Geon, Geoa) */
'  G_UNICODE_SCRIPT_GOTHIC,             /* Goth */
'  G_UNICODE_SCRIPT_GREEK,              /* Grek */
'  G_UNICODE_SCRIPT_GUJARATI,           /* Gujr */
'  G_UNICODE_SCRIPT_GURMUKHI,           /* Guru */
'  G_UNICODE_SCRIPT_HAN,                /* Hani */
'  G_UNICODE_SCRIPT_HANGUL,             /* Hang */
'  G_UNICODE_SCRIPT_HEBREW,             /* Hebr */
'  G_UNICODE_SCRIPT_HIRAGANA,           /* Hira */
'  G_UNICODE_SCRIPT_KANNADA,            /* Knda */
'  G_UNICODE_SCRIPT_KATAKANA,           /* Kana */
'  G_UNICODE_SCRIPT_KHMER,              /* Khmr */
'  G_UNICODE_SCRIPT_LAO,                /* Laoo */
'  G_UNICODE_SCRIPT_LATIN,              /* Latn (Latf, Latg) */
'  G_UNICODE_SCRIPT_MALAYALAM,          /* Mlym */
'  G_UNICODE_SCRIPT_MONGOLIAN,          /* Mong */
'  G_UNICODE_SCRIPT_MYANMAR,            /* Mymr */
'  G_UNICODE_SCRIPT_OGHAM,              /* Ogam */
'  G_UNICODE_SCRIPT_OLD_ITALIC,         /* Ital */
'  G_UNICODE_SCRIPT_ORIYA,              /* Orya */
'  G_UNICODE_SCRIPT_RUNIC,              /* Runr */
'  G_UNICODE_SCRIPT_SINHALA,            /* Sinh */
'  G_UNICODE_SCRIPT_SYRIAC,             /* Syrc (Syrj, Syrn, Syre) */
'  G_UNICODE_SCRIPT_TAMIL,              /* Taml */
'  G_UNICODE_SCRIPT_TELUGU,             /* Telu */
'  G_UNICODE_SCRIPT_THAANA,             /* Thaa */
'  G_UNICODE_SCRIPT_THAI,               /* Thai */
'  G_UNICODE_SCRIPT_TIBETAN,            /* Tibt */
'  G_UNICODE_SCRIPT_CANADIAN_ABORIGINAL, /* Cans */
'  G_UNICODE_SCRIPT_YI,                 /* Yiii */
'  G_UNICODE_SCRIPT_TAGALOG,            /* Tglg */
'  G_UNICODE_SCRIPT_HANUNOO,            /* Hano */
'  G_UNICODE_SCRIPT_BUHID,              /* Buhd */
'  G_UNICODE_SCRIPT_TAGBANWA,           /* Tagb */

'  /* Unicode-4.0 additions */
'  G_UNICODE_SCRIPT_BRAILLE,            /* Brai */
'  G_UNICODE_SCRIPT_CYPRIOT,            /* Cprt */
'  G_UNICODE_SCRIPT_LIMBU,              /* Limb */
'  G_UNICODE_SCRIPT_OSMANYA,            /* Osma */
'  G_UNICODE_SCRIPT_SHAVIAN,            /* Shaw */
'  G_UNICODE_SCRIPT_LINEAR_B,           /* Linb */
'  G_UNICODE_SCRIPT_TAI_LE,             /* Tale */
'  G_UNICODE_SCRIPT_UGARITIC,           /* Ugar */

'  /* Unicode-4.1 additions */
'  G_UNICODE_SCRIPT_NEW_TAI_LUE,        /* Talu */
'  G_UNICODE_SCRIPT_BUGINESE,           /* Bugi */
'  G_UNICODE_SCRIPT_GLAGOLITIC,         /* Glag */
'  G_UNICODE_SCRIPT_TIFINAGH,           /* Tfng */
'  G_UNICODE_SCRIPT_SYLOTI_NAGRI,       /* Sylo */
'  G_UNICODE_SCRIPT_OLD_PERSIAN,        /* Xpeo */
'  G_UNICODE_SCRIPT_KHAROSHTHI,         /* Khar */

'  /* Unicode-5.0 additions */
'  G_UNICODE_SCRIPT_UNKNOWN,            /* Zzzz */
'  G_UNICODE_SCRIPT_BALINESE,           /* Bali */
'  G_UNICODE_SCRIPT_CUNEIFORM,          /* Xsux */
'  G_UNICODE_SCRIPT_PHOENICIAN,         /* Phnx */
'  G_UNICODE_SCRIPT_PHAGS_PA,           /* Phag */
'  G_UNICODE_SCRIPT_NKO,                /* Nkoo */

'  /* Unicode-5.1 additions */
'  G_UNICODE_SCRIPT_KAYAH_LI,           /* Kali */
'  G_UNICODE_SCRIPT_LEPCHA,             /* Lepc */
'  G_UNICODE_SCRIPT_REJANG,             /* Rjng */
'  G_UNICODE_SCRIPT_SUNDANESE,          /* Sund */
'  G_UNICODE_SCRIPT_SAURASHTRA,         /* Saur */
'  G_UNICODE_SCRIPT_CHAM,               /* Cham */
'  G_UNICODE_SCRIPT_OL_CHIKI,           /* Olck */
'  G_UNICODE_SCRIPT_VAI,                /* Vaii */
'  G_UNICODE_SCRIPT_CARIAN,             /* Cari */
'  G_UNICODE_SCRIPT_LYCIAN,             /* Lyci */
'  G_UNICODE_SCRIPT_LYDIAN              /* Lydi */
'} GUnicodeScript;

%G_UNICODE_SCRIPT_INVALID_CODE        = -1
%G_UNICODE_SCRIPT_COMMON              = 0    ' /* Zyyy */
%G_UNICODE_SCRIPT_INHERITED           = 1    ' /* Qaai */
%G_UNICODE_SCRIPT_ARABIC              = 2    ' /* Arab */
%G_UNICODE_SCRIPT_ARMENIAN            = 3    ' /* Armn */
%G_UNICODE_SCRIPT_BENGALI             = 4    ' /* Beng */
%G_UNICODE_SCRIPT_BOPOMOFO            = 5    ' /* Bopo */
%G_UNICODE_SCRIPT_CHEROKEE            = 6    ' /* Cher */
%G_UNICODE_SCRIPT_COPTIC              = 7    ' /* Qaac */
%G_UNICODE_SCRIPT_CYRILLIC            = 8    ' /* Cyrl (Cyrs) */
%G_UNICODE_SCRIPT_DESERET             = 9    ' /* Dsrt */
%G_UNICODE_SCRIPT_DEVANAGARI          = 10   ' /* Deva */
%G_UNICODE_SCRIPT_ETHIOPIC            = 11   ' /* Ethi */
%G_UNICODE_SCRIPT_GEORGIAN            = 12   ' /* Geor (Geon = Geoa) */
%G_UNICODE_SCRIPT_GOTHIC              = 13   ' /* Goth */
%G_UNICODE_SCRIPT_GREEK               = 14   ' /* Grek */
%G_UNICODE_SCRIPT_GUJARATI            = 15   ' /* Gujr */
%G_UNICODE_SCRIPT_GURMUKHI            = 16   ' /* Guru */
%G_UNICODE_SCRIPT_HAN                 = 17   ' /* Hani */
%G_UNICODE_SCRIPT_HANGUL              = 18   ' /* Hang */
%G_UNICODE_SCRIPT_HEBREW              = 19   ' /* Hebr */
%G_UNICODE_SCRIPT_HIRAGANA            = 20   ' /* Hira */
%G_UNICODE_SCRIPT_KANNADA             = 21   ' /* Knda */
%G_UNICODE_SCRIPT_KATAKANA            = 22   ' /* Kana */
%G_UNICODE_SCRIPT_KHMER               = 23   ' /* Khmr */
%G_UNICODE_SCRIPT_LAO                 = 24   ' /* Laoo */
%G_UNICODE_SCRIPT_LATIN               = 25   ' /* Latn (Latf = Latg) */
%G_UNICODE_SCRIPT_MALAYALAM           = 26   ' /* Mlym */
%G_UNICODE_SCRIPT_MONGOLIAN           = 27   ' /* Mong */
%G_UNICODE_SCRIPT_MYANMAR             = 28   ' /* Mymr */
%G_UNICODE_SCRIPT_OGHAM               = 29   ' /* Ogam */
%G_UNICODE_SCRIPT_OLD_ITALIC          = 30   ' /* Ital */
%G_UNICODE_SCRIPT_ORIYA               = 31   ' /* Orya */
%G_UNICODE_SCRIPT_RUNIC               = 32   ' /* Runr */
%G_UNICODE_SCRIPT_SINHALA             = 33   ' /* Sinh */
%G_UNICODE_SCRIPT_SYRIAC              = 34   ' /* Syrc (Syrj = Syrn = Syre) */
%G_UNICODE_SCRIPT_TAMIL               = 35   ' /* Taml */
%G_UNICODE_SCRIPT_TELUGU              = 36   ' /* Telu */
%G_UNICODE_SCRIPT_THAANA              = 37   ' /* Thaa */
%G_UNICODE_SCRIPT_THAI                = 38   ' /* Thai */
%G_UNICODE_SCRIPT_TIBETAN             = 39   ' /* Tibt */
%G_UNICODE_SCRIPT_CANADIAN_ABORIGINAL = 40   ' /* Cans */
%G_UNICODE_SCRIPT_YI                  = 41   ' /* Yiii */
%G_UNICODE_SCRIPT_TAGALOG             = 42   ' /* Tglg */
%G_UNICODE_SCRIPT_HANUNOO             = 43   ' /* Hano */
%G_UNICODE_SCRIPT_BUHID               = 44   ' /* Buhd */
%G_UNICODE_SCRIPT_TAGBANWA            = 45   ' /* Tagb */

  ' /* Unicode-4.0 additions */
%G_UNICODE_SCRIPT_BRAILLE             = 46   ' /* Brai */
%G_UNICODE_SCRIPT_CYPRIOT             = 47   ' /* Cprt */
%G_UNICODE_SCRIPT_LIMBU               = 48   ' /* Limb */
%G_UNICODE_SCRIPT_OSMANYA             = 49   ' /* Osma */
%G_UNICODE_SCRIPT_SHAVIAN             = 50   ' /* Shaw */
%G_UNICODE_SCRIPT_LINEAR_B            = 51   ' /* Linb */
%G_UNICODE_SCRIPT_TAI_LE              = 52   ' /* Tale */
%G_UNICODE_SCRIPT_UGARITIC            = 53   ' /* Ugar */

  ' /* Unicode-4.1 additions */
%G_UNICODE_SCRIPT_NEW_TAI_LUE         = 54   ' /* Talu */
%G_UNICODE_SCRIPT_BUGINESE            = 55   ' /* Bugi */
%G_UNICODE_SCRIPT_GLAGOLITIC          = 56   ' /* Glag */
%G_UNICODE_SCRIPT_TIFINAGH            = 57   ' /* Tfng */
%G_UNICODE_SCRIPT_SYLOTI_NAGRI        = 58   ' /* Sylo */
%G_UNICODE_SCRIPT_OLD_PERSIAN         = 59   ' /* Xpeo */
%G_UNICODE_SCRIPT_KHAROSHTHI          = 60   ' /* Khar */

  ' /* Unicode-5.0 additions */
%G_UNICODE_SCRIPT_UNKNOWN             = 61   ' /* Zzzz */
%G_UNICODE_SCRIPT_BALINESE            = 62   ' /* Bali */
%G_UNICODE_SCRIPT_CUNEIFORM           = 63   ' /* Xsux */
%G_UNICODE_SCRIPT_PHOENICIAN          = 64   ' /* Phnx */
%G_UNICODE_SCRIPT_PHAGS_PA            = 65   ' /* Phag */
%G_UNICODE_SCRIPT_NKO                 = 66   ' /* Nkoo */

  ' /* Unicode-5.1 additions */
%G_UNICODE_SCRIPT_KAYAH_LI            = 67   ' /* Kali */
%G_UNICODE_SCRIPT_LEPCHA              = 68   ' /* Lepc */
%G_UNICODE_SCRIPT_REJANG              = 69   ' /* Rjng */
%G_UNICODE_SCRIPT_SUNDANESE           = 70   ' /* Sund */
%G_UNICODE_SCRIPT_SAURASHTRA          = 71   ' /* Saur */
%G_UNICODE_SCRIPT_CHAM                = 72   ' /* Cham */
%G_UNICODE_SCRIPT_OL_CHIKI            = 73   ' /* Olck */
%G_UNICODE_SCRIPT_VAI                 = 74   ' /* Vaii */
%G_UNICODE_SCRIPT_CARIAN              = 75   ' /* Cari */
%G_UNICODE_SCRIPT_LYCIAN              = 76   ' /* Lyci */
%G_UNICODE_SCRIPT_LYDIAN              = 77   ' /* Lydi */

'/* Returns TRUE if current locale uses UTF-8 charset.  If CHARSET is
' * not null, sets *CHARSET to the name of the current locale's
' * charset.  This value is statically allocated, and should be copied
' * in case the locale's charset will be changed later using setlocale()
' * or in some other way.
' */

' ========================================================================================
'gboolean g_get_charset (G_CONST_RETURN char **charset);
' Usage:
' DIM bRes AS LONG
' DIM psz AS ASCIIZ PTR
' DIM strCharset AS STRING
' bRes = g_get_charset(psz)
' IF psz THEN strCharset = @psz
' ========================================================================================
DECLARE FUNCTION g_get_charset CDECL LIB $GLIB_DLLNAME ALIAS "g_get_charset" ( _
   BYREF DWORD _                            ' G_CONST_RETURN char **charset
 ) AS LONG                                  ' gboolean

'/* These are all analogs of the <ctype.h> functions.
' */

' ========================================================================================
'gboolean g_unichar_isalnum   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isalnum CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isalnum" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isalpha   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isalpha CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isalpha" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_iscntrl   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_iscntrl CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_iscntrl" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isdigit   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isdigit CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isdigit" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isgraph   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isgraph CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isgraph" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_islower   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_islower CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_islower" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isprint   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isprint CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isprint" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_ispunct   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_ispunct CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_ispunct" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isspace   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isspace CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isspace" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isupper   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isupper CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isupper" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isxdigit  (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isxdigit CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isxdigit" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_istitle   (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_istitle CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_istitle" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_isdefined (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_isdefined CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_isdefined" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_iswide    (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_iswide CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_iswide" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_iswide_cjk(gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_iswide_cjk CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_iswide_cjk" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_iszerowidth(gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_iszerowidth CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_iszerowidth" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gboolean g_unichar_ismark    (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_ismark CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_ismark" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gboolean

'/* More <ctype.h> functions.  These convert between the three cases.
' * See the Unicode book to understand title case.  */

' ========================================================================================
'gunichar g_unichar_toupper (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_toupper CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_toupper" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS DWORD                                 ' gunichar

' ========================================================================================
'gunichar g_unichar_tolower (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_tolower CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_tolower" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS DWORD                                 ' gunichar

' ========================================================================================
'gunichar g_unichar_totitle (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_totitle CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_totitle" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS DWORD                                 ' gunichar

'/* If C is a digit (according to `g_unichar_isdigit'), then return its
'   numeric value.  Otherwise return -1.  */

' ========================================================================================
'gint g_unichar_digit_value (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_digit_value CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_digit_value" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gint

' ========================================================================================
'gint g_unichar_xdigit_value (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_xdigit_value CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_xdigit_value" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' gint

'/* Return the Unicode character type of a given character.  */

' ========================================================================================
'GUnicodeType g_unichar_type (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_type CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_type" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' GUnicodeType

'/* Return the line break property for a given character */

' ========================================================================================
'GUnicodeBreakType g_unichar_break_type (gunichar c) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_break_type CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_break_type" ( _
   BYVAL DWORD _                            ' gunichar c
 ) AS LONG                                  ' GUnicodeBreakType

'/* Returns the combining class for a given character */

' ========================================================================================
'gint g_unichar_combining_class (gunichar uc) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_combining_class CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_combining_class" ( _
   BYVAL DWORD _                            ' gunichar uc
 ) AS LONG                                  ' gint


'/* Compute canonical ordering of a string in-place.  This rearranges
'   decomposed characters in the string according to their combining
'   classes.  See the Unicode manual for more information.  */

' ========================================================================================
'void g_unicode_canonical_ordering (gunichar *string,
'                                   gsize     len);
' ========================================================================================
DECLARE SUB g_unicode_canonical_ordering CDECL LIB $GLIB_DLLNAME ALIAS "g_unicode_canonical_ordering" ( _
   BYVAL DWORD _                            ' gunichar *string
 , BYVAL DWORD _                            ' gsize     len
 )                                          ' void

'/* Compute canonical decomposition of a character.  Returns g_malloc()d
'   string of Unicode characters.  RESULT_LEN is set to the resulting
'   length of the string.  */

' ========================================================================================
'gunichar *g_unicode_canonical_decomposition (gunichar  ch,
'                                             gsize    *result_len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_unicode_canonical_decomposition CDECL LIB $GLIB_DLLNAME ALIAS "g_unicode_canonical_decomposition" ( _
   BYVAL DWORD _                            ' gunichar  ch
 , BYREF DWORD _                            ' gsize    *result_len
 ) AS DWORD                                 ' gunichar

'/* Array of skip-bytes-per-initial character.
' */

' ========================================================================================
'GLIB_VAR const gchar * const g_utf8_skip;
' ========================================================================================

' ========================================================================================
'#define g_utf8_next_char(p) (char *)((p) + g_utf8_skip[*(const guchar *)(p)])
' ========================================================================================

' ========================================================================================
'gunichar g_utf8_get_char           (const gchar  *p) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_get_char CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_get_char" ( _
   BYREF ASCIIZ _                           ' const gchar  *p
 ) AS DWORD                                 ' gunichar

' ========================================================================================
'gunichar g_utf8_get_char_validated (const  gchar *p,
'                                    gssize        max_len) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_get_char_validated CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_get_char_validated" ( _
   BYREF ASCIIZ _                           ' const gchar  *p
 , BYVAL LONG _                             ' gssize        max_len
 ) AS DWORD                                 ' gunichar

' ========================================================================================
'gchar*   g_utf8_offset_to_pointer (const gchar *str,
'                                   glong        offset) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_offset_to_pointer CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_offset_to_pointer" ( _
   BYREF ASCIIZ _                           ' const gchar  *str
 , BYVAL LONG _                             ' glong         offset
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'glong    g_utf8_pointer_to_offset (const gchar *str,
'                                   const gchar *pos) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_pointer_to_offset CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_pointer_to_offset" ( _
   BYREF ASCIIZ _                           ' const gchar  *str
 , BYVAL DWORD _                            ' const gchar  *pos
 ) AS LONG                                  ' glong

' ========================================================================================
'gchar*   g_utf8_prev_char         (const gchar *p) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_prev_char CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_prev_char" ( _
   BYVAL DWORD _                            ' const gchar  *p
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar*   g_utf8_find_next_char    (const gchar *p,
'                                   const gchar *end) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_find_next_char CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_find_next_char" ( _
   BYVAL DWORD _                            ' const gchar  *p
 , BYVAL DWORD _                            ' const gchar  *end
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar*   g_utf8_find_prev_char    (const gchar *str,
'                                   const gchar *p) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_find_prev_char CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_find_prev_char" ( _
   BYREF ASCIIZ _                           ' const gchar  *str
 , BYVAL DWORD _                            ' const gchar  *p
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'glong g_utf8_strlen (const gchar *p,
'                     gssize       max) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_strlen CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strlen" ( _
   BYREF ASCIIZ _                           ' const gchar *p
 , BYVAL LONG _                             ' gssize       max
 ) AS LONG                                  ' glong

'/* Copies n characters from src to dest */

' ========================================================================================
'gchar* g_utf8_strncpy (gchar       *dest,
'                       const gchar *src,
'                       gsize        n);
' ========================================================================================
DECLARE FUNCTION g_utf8_strncpy CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strncpy" ( _
   BYREF ASCIIZ _                           ' gchar       *dest
 , BYREF ASCIIZ _                           ' const gchar *src
 , BYVAL DWORD _                            ' gsize        n
 ) AS DWORD                                 ' gchar*

'/* Find the UTF-8 character corresponding to ch, in string p. These
'   functions are equivalants to strchr and strrchr */

' ========================================================================================
'gchar* g_utf8_strchr  (const gchar *p,
'                       gssize       len,
'                       gunichar     c);
' ========================================================================================
DECLARE FUNCTION g_utf8_strchr CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strchr" ( _
   BYREF ASCIIZ _                           ' gchar       *p
 , BYVAL LONG _                             ' gssize       len
 , BYVAL DWORD _                            ' gunichar     c
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar* g_utf8_strrchr (const gchar *p,
'                       gssize       len,
'                       gunichar     c);
' ========================================================================================
DECLARE FUNCTION g_utf8_strrchr CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strrchr" ( _
   BYREF ASCIIZ _                           ' gchar       *p
 , BYVAL LONG _                             ' gssize       len
 , BYVAL DWORD _                            ' gunichar     c
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar* g_utf8_strreverse (const gchar *str,
'                          gssize len);
' ========================================================================================
DECLARE FUNCTION g_utf8_strreverse CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strreverse" ( _
   BYREF ASCIIZ _                           ' gchar       *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gunichar2 *g_utf8_to_utf16     (const gchar      *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_to_utf16 CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_to_utf16" ( _
   BYREF ASCIIZ _                           ' const gchar      *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gunichar2*

' ========================================================================================
'gunichar * g_utf8_to_ucs4      (const gchar      *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_to_ucs4 CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_to_ucs4" ( _
   BYREF ASCIIZ _                           ' const gchar      *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gunichar*

' ========================================================================================
'gunichar * g_utf8_to_ucs4_fast (const gchar      *str,
'                                glong             len,
'                                glong            *items_written) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_to_ucs4_fast CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_to_ucs4_fast" ( _
   BYREF ASCIIZ _                           ' const gchar      *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_written
 ) AS DWORD                                 ' gunichar*

' ========================================================================================
'gunichar * g_utf16_to_ucs4     (const gunichar2  *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf16_to_ucs4 CDECL LIB $GLIB_DLLNAME ALIAS "g_utf16_to_ucs4" ( _
   BYVAL DWORD _                            ' const gunichar2  *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gunichar*

' ========================================================================================
'gchar*     g_utf16_to_utf8     (const gunichar2  *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf16_to_utf8 CDECL LIB $GLIB_DLLNAME ALIAS "g_utf16_to_utf8" ( _
   BYVAL DWORD _                            ' const gunichar2  *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gunichar2 *g_ucs4_to_utf16     (const gunichar   *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_ucs4_to_utf16 CDECL LIB $GLIB_DLLNAME ALIAS "g_ucs4_to_utf16" ( _
   BYVAL DWORD _                            ' const gunichar   *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gunichar2*

' ========================================================================================
'gchar*     g_ucs4_to_utf8      (const gunichar   *str,
'                                glong             len,
'                                glong            *items_read,
'                                glong            *items_written,
'                                GError          **error) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_ucs4_to_utf8 CDECL LIB $GLIB_DLLNAME ALIAS "g_ucs4_to_utf8" ( _
   BYVAL DWORD _                            ' const gunichar2  *str
 , BYVAL LONG _                             ' glong             len
 , BYREF LONG _                             ' glong            *items_read
 , BYREF LONG _                             ' glong            *items_written
 , BYREF DWORD _                            ' GError          **error
 ) AS DWORD                                 ' gchar*

'/* Convert a single character into UTF-8. outbuf must have at
' * least 6 bytes of space. Returns the number of bytes in the
' * result.
' */

' ========================================================================================
'gint      g_unichar_to_utf8 (gunichar    c,
'                             gchar      *outbuf);
' ========================================================================================
DECLARE FUNCTION g_unichar_to_utf8 CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_to_utf8" ( _
   BYVAL WORD _                             ' gunichar    c
 , BYREF ASCIIZ _                           ' gchar      *outbuf
 ) AS LONG                                  ' gint

'/* Validate a UTF8 string, return TRUE if valid, put pointer to
' * first invalid char in **end
' */

' ========================================================================================
'gboolean g_utf8_validate (const gchar  *str,
'                          gssize        max_len,
'                          const gchar **end);
' ========================================================================================
DECLARE FUNCTION g_utf8_validate CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_validate" ( _
   BYREF ASCIIZ _                           ' const gchar  *str
 , BYVAL LONG _                             ' gssize        max_len
 , BYREF DWORD _                            ' const gchar **end
 ) AS LONG                                  ' gboolean

'/* Validate a Unicode character */

' ========================================================================================
'gboolean g_unichar_validate (gunichar ch) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_validate CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_validate" ( _
   BYVAL DWORD _                            ' gunichar ch
 ) AS LONG                                  ' gboolean

' ========================================================================================
'gchar *g_utf8_strup   (const gchar *str,
'                       gssize       len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_strup CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strup" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_utf8_strdown (const gchar *str,
'                       gssize       len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_strdown CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_strdown" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_utf8_casefold (const gchar *str,
'                        gssize       len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_casefold CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_casefold" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

'typedef enum {
'  G_NORMALIZE_DEFAULT,
'  G_NORMALIZE_NFD = G_NORMALIZE_DEFAULT,
'  G_NORMALIZE_DEFAULT_COMPOSE,
'  G_NORMALIZE_NFC = G_NORMALIZE_DEFAULT_COMPOSE,
'  G_NORMALIZE_ALL,
'  G_NORMALIZE_NFKD = G_NORMALIZE_ALL,
'  G_NORMALIZE_ALL_COMPOSE,
'  G_NORMALIZE_NFKC = G_NORMALIZE_ALL_COMPOSE
'} GNormalizeMode;

%G_NORMALIZE_DEFAULT         = 0
%G_NORMALIZE_NFD             = %G_NORMALIZE_DEFAULT
%G_NORMALIZE_DEFAULT_COMPOSE = 1
%G_NORMALIZE_NFC             = %G_NORMALIZE_DEFAULT_COMPOSE
%G_NORMALIZE_ALL             = 2
%G_NORMALIZE_NFKD            = %G_NORMALIZE_ALL
%G_NORMALIZE_ALL_COMPOSE     = 3
%G_NORMALIZE_NFKC            = %G_NORMALIZE_ALL_COMPOSE

' ========================================================================================
'gchar *g_utf8_normalize (const gchar   *str,
'                         gssize         len,
'                         GNormalizeMode mode) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_normalize CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_normalize" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 , BYVAL LONG _                             ' GNormalizeMode mode
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gint   g_utf8_collate     (const gchar *str1,
'                           const gchar *str2) G_GNUC_PURE;
' ========================================================================================
DECLARE FUNCTION g_utf8_collate CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_collate" ( _
   BYREF ASCIIZ _                           ' const gchar *str1
 , BYREF ASCIIZ _                           ' const gchar *str2
 ) AS LONG                                  ' gint

' ========================================================================================
'gchar *g_utf8_collate_key (const gchar *str,
'                           gssize       len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_collate_key CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_collate_key" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gchar *g_utf8_collate_key_for_filename (const gchar *str,
'                                        gssize       len) G_GNUC_MALLOC;
' ========================================================================================
DECLARE FUNCTION g_utf8_collate_key_for_filename CDECL LIB $GLIB_DLLNAME ALIAS "g_utf8_collate_key_for_filename" ( _
   BYREF ASCIIZ _                           ' const gchar *str
 , BYVAL LONG _                             ' gssize       len
 ) AS DWORD                                 ' gchar*

' ========================================================================================
'gboolean g_unichar_get_mirror_char (gunichar ch,
'                                    gunichar *mirrored_ch);
' ========================================================================================
DECLARE FUNCTION g_unichar_get_mirror_char CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_get_mirror_char" ( _
   BYVAL DWORD _                            ' gunichar ch
 , BYVAL DWORD _                            ' gunichar *mirrored_ch
 ) AS LONG                                  ' gboolean

' ========================================================================================
'GUnicodeScript g_unichar_get_script (gunichar ch) G_GNUC_CONST;
' ========================================================================================
DECLARE FUNCTION g_unichar_get_script CDECL LIB $GLIB_DLLNAME ALIAS "g_unichar_get_script" ( _
   BYVAL DWORD _                            ' gunichar ch
 ) AS LONG                                  ' gboolean


'/* private */

'gchar *_g_utf8_make_valid (const gchar *name);

'G_END_DECLS

'#endif /* __G_UNICODE_H__ */
#ENDIF   ' /* __GUNICODE_INC__ */
